@@ -19,20 +19,31 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#include "main.h"
 #include "bar-comment.h"
 
+#include <cstring>
+
+#include <config.h>
+
+#include <gdk/gdk.h>
+#include <glib-object.h>
+#if HAVE_SPELL
+#  include <gspell/gspell.h>
+#endif
+
 #include "bar.h"
-#include "metadata.h"
+#include "compat.h"
+#include "debug.h"
 #include "filedata.h"
+#include "intl.h"
+#include "layout.h"
+#include "main-defines.h"
+#include "metadata.h"
+#include "options.h"
+#include "rcfile.h"
+#include "typedefs.h"
 #include "ui-menu.h"
 #include "ui-misc.h"
-#include "rcfile.h"
-#include "layout.h"
-
-#ifdef HAVE_SPELL
-#include <gspell/gspell.h>
-#endif
 
 static void bar_pane_comment_changed(GtkTextBuffer *buffer, gpointer data);
 
@@ -52,7 +63,7 @@ struct PaneCommentData
 	FileData *fd;
 	gchar *key;
 	gint height;
-#ifdef HAVE_SPELL
+#if HAVE_SPELL
 	GspellTextView *gspell_view;
 #endif
 };
@@ -178,7 +189,8 @@ static gint bar_pane_comment_event(GtkWidget *bar, GdkEvent *event)
 static void bar_pane_comment_write_config(GtkWidget *pane, GString *outstr, gint indent)
 {
 	PaneCommentData *pcd;
-	gint w, h;
+	gint w;
+	gint h;
 
 	pcd = static_cast<PaneCommentData *>(g_object_get_data(G_OBJECT(pane), "pane_data"));
 	if (!pcd) return;
@@ -244,8 +256,8 @@ static void bar_pane_comment_destroy(GtkWidget *, gpointer data)
 	auto pcd = static_cast<PaneCommentData *>(data);
 
 	file_data_unregister_notify_func(bar_pane_comment_notify_cb, pcd);
-#ifdef HAVE_SPELL
-	g_object_unref(pcd->gspell_view);
+#if HAVE_SPELL
+	gtk_container_remove(GTK_CONTAINER(gtk_widget_get_parent(pcd->comment_view)), pcd->comment_view);
 #endif
 	file_data_unref(pcd->fd);
 	g_free(pcd->key);
@@ -270,7 +282,7 @@ static GtkWidget *bar_pane_comment_new(const gchar *id, const gchar *title, cons
 	pcd->pane.title = bar_pane_expander_title(title);
 	pcd->pane.id = g_strdup(id);
 	pcd->pane.type = PANE_COMMENT;
-#ifdef HAVE_SPELL
+#if HAVE_SPELL
 	pcd->gspell_view = nullptr;
 #endif
 	pcd->pane.expanded = expanded;
@@ -299,7 +311,7 @@ static GtkWidget *bar_pane_comment_new(const gchar *id, const gchar *title, cons
 			 G_CALLBACK(bar_pane_comment_populate_popup), pcd);
 	gtk_widget_show(pcd->comment_view);
 
-#ifdef HAVE_SPELL
+#if HAVE_SPELL
 	if (g_strcmp0(key, "Xmp.xmp.Rating") != 0)
 		{
 		if (options->metadata.check_spelling)
