@@ -19,22 +19,38 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#include "main.h"
 #include "bar-exif.h"
 
+#include <cstring>
+
+#include <gdk/gdk.h>
+#include <glib-object.h>
+#include <pango/pango.h>
+
+#include <config.h>
+
 #include "bar.h"
+#include "compat.h"
+#include "debug.h"
 #include "dnd.h"
 #include "exif.h"
 #include "filedata.h"
+#include "intl.h"
 #include "layout.h"
+#include "main-defines.h"
 #include "metadata.h"
 #include "misc.h"
 #include "rcfile.h"
+#include "typedefs.h"
 #include "ui-menu.h"
 #include "ui-misc.h"
 #include "ui-utildlg.h"
 
-#define MIN_HEIGHT 25
+namespace
+{
+
+constexpr gint MIN_HEIGHT = 25;
+
 /*
  *-------------------------------------------------------------------
  * EXIF widget
@@ -87,14 +103,14 @@ struct ConfDialogData
 	gboolean editable;
 };
 
-static void bar_pane_exif_entry_dnd_init(GtkWidget *entry);
-static void bar_pane_exif_entry_update_title(ExifEntry *ee);
-static void bar_pane_exif_update(PaneExifData *ped);
-static gboolean bar_pane_exif_menu_cb(GtkWidget *widget, GdkEventButton *bevent, gpointer data);
-static void bar_pane_exif_notify_cb(FileData *fd, NotifyType type, gpointer data);
-static gboolean bar_pane_exif_copy_cb(GtkWidget *widget, GdkEventButton *bevent, gpointer data);
+void bar_pane_exif_entry_dnd_init(GtkWidget *entry);
+void bar_pane_exif_entry_update_title(ExifEntry *ee);
+void bar_pane_exif_update(PaneExifData *ped);
+gboolean bar_pane_exif_menu_cb(GtkWidget *widget, GdkEventButton *bevent, gpointer data);
+void bar_pane_exif_notify_cb(FileData *fd, NotifyType type, gpointer data);
+gboolean bar_pane_exif_copy_cb(GtkWidget *widget, GdkEventButton *bevent, gpointer data);
 
-static void bar_pane_exif_entry_changed(GtkEntry *, gpointer data)
+void bar_pane_exif_entry_changed(GtkEntry *, gpointer data)
 {
 	auto ee = static_cast<ExifEntry *>(data);
 	gchar *text;
@@ -105,7 +121,7 @@ static void bar_pane_exif_entry_changed(GtkEntry *, gpointer data)
 	g_free(text);
 }
 
-static void bar_pane_exif_entry_destroy(GtkWidget *, gpointer data)
+void bar_pane_exif_entry_destroy(GtkWidget *, gpointer data)
 {
 	auto ee = static_cast<ExifEntry *>(data);
 
@@ -114,12 +130,15 @@ static void bar_pane_exif_entry_destroy(GtkWidget *, gpointer data)
 	g_free(ee);
 }
 
-static void bar_pane_exif_setup_entry_box(PaneExifData *ped, ExifEntry *ee)
+void bar_pane_exif_setup_entry_box(PaneExifData *ped, ExifEntry *ee)
 {
 	gboolean horizontal = !ee->editable;
 	gboolean editable = ee->editable;
 
-	if (ee->box) g_object_unref(ee->box);
+	if (ee->box)
+		{
+		gtk_container_remove(GTK_CONTAINER(gtk_widget_get_parent(ee->box)), ee->box);
+		}
 
 	ee->box = horizontal ? gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0) : gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
 	gq_gtk_container_add(GTK_WIDGET(ee->ebox), ee->box);
@@ -151,7 +170,7 @@ static void bar_pane_exif_setup_entry_box(PaneExifData *ped, ExifEntry *ee)
 	gtk_widget_show(ee->value_widget);
 }
 
-static GtkWidget *bar_pane_exif_add_entry(PaneExifData *ped, const gchar *key, const gchar *title, gboolean if_set, gboolean editable)
+GtkWidget *bar_pane_exif_add_entry(PaneExifData *ped, const gchar *key, const gchar *title, gboolean if_set, gboolean editable)
 {
 	auto ee = g_new0(ExifEntry, 1);
 
@@ -190,7 +209,7 @@ static GtkWidget *bar_pane_exif_add_entry(PaneExifData *ped, const gchar *key, c
 	return ee->ebox;
 }
 
-static void bar_pane_exif_reparent_entry(GtkWidget *entry, GtkWidget *pane)
+void bar_pane_exif_reparent_entry(GtkWidget *entry, GtkWidget *pane)
 {
 	auto ped = static_cast<PaneExifData *>(g_object_get_data(G_OBJECT(pane), "pane_data"));
 	PaneExifData *old_ped;
@@ -210,7 +229,7 @@ static void bar_pane_exif_reparent_entry(GtkWidget *entry, GtkWidget *pane)
 	gq_gtk_box_pack_start(GTK_BOX(ped->vbox), entry, FALSE, FALSE, 0);
 }
 
-static void bar_pane_exif_entry_update_title(ExifEntry *ee)
+void bar_pane_exif_entry_update_title(ExifEntry *ee)
 {
 	gchar *markup;
 
@@ -219,7 +238,7 @@ static void bar_pane_exif_entry_update_title(ExifEntry *ee)
 	g_free(markup);
 }
 
-static void bar_pane_exif_update_entry(PaneExifData *ped, GtkWidget *entry, gboolean update_title)
+void bar_pane_exif_update_entry(PaneExifData *ped, GtkWidget *entry, gboolean update_title)
 {
 	gchar *text;
 	auto ee = static_cast<ExifEntry *>(g_object_get_data(G_OBJECT(entry), "entry_data"));
@@ -264,9 +283,10 @@ static void bar_pane_exif_update_entry(PaneExifData *ped, GtkWidget *entry, gboo
 	if (update_title) bar_pane_exif_entry_update_title(ee);
 }
 
-static void bar_pane_exif_update(PaneExifData *ped)
+void bar_pane_exif_update(PaneExifData *ped)
 {
-	GList *list, *work;
+	GList *list;
+	GList *work;
 
 	ped->all_hidden = TRUE;
 
@@ -284,7 +304,7 @@ static void bar_pane_exif_update(PaneExifData *ped)
 	gtk_widget_set_sensitive(ped->pane.title, !ped->all_hidden);
 }
 
-static void bar_pane_exif_set_fd(GtkWidget *widget, FileData *fd)
+void bar_pane_exif_set_fd(GtkWidget *widget, FileData *fd)
 {
 	PaneExifData *ped;
 
@@ -297,11 +317,12 @@ static void bar_pane_exif_set_fd(GtkWidget *widget, FileData *fd)
 	bar_pane_exif_update(ped);
 }
 
-static gint bar_pane_exif_event(GtkWidget *bar, GdkEvent *event)
+gint bar_pane_exif_event(GtkWidget *bar, GdkEvent *event)
 {
 	PaneExifData *ped;
 	gboolean ret = FALSE;
-	GList *list, *work;
+	GList *list;
+	GList *work;
 
 	ped = static_cast<PaneExifData *>(g_object_get_data(G_OBJECT(bar), "pane_data"));
 	if (!ped) return FALSE;
@@ -320,7 +341,7 @@ static gint bar_pane_exif_event(GtkWidget *bar, GdkEvent *event)
 	return ret;
 }
 
-static void bar_pane_exif_notify_cb(FileData *fd, NotifyType type, gpointer data)
+void bar_pane_exif_notify_cb(FileData *fd, NotifyType type, gpointer data)
 {
 	auto ped = static_cast<PaneExifData *>(data);
 	if ((type & (NOTIFY_REREAD | NOTIFY_CHANGE | NOTIFY_METADATA)) && fd == ped->fd)
@@ -337,20 +358,22 @@ static void bar_pane_exif_notify_cb(FileData *fd, NotifyType type, gpointer data
  *-------------------------------------------------------------------
  */
 
-static GtkTargetEntry bar_pane_exif_drag_types[] = {
+// @todo Use std::array
+constexpr GtkTargetEntry bar_pane_exif_drag_types[] = {
 	{ const_cast<gchar *>(TARGET_APP_EXIF_ENTRY_STRING), GTK_TARGET_SAME_APP, TARGET_APP_EXIF_ENTRY },
 	{ const_cast<gchar *>("text/plain"), 0, TARGET_TEXT_PLAIN }
 };
-static gint n_exif_entry_drag_types = 2;
+constexpr gint n_exif_entry_drag_types = 2;
 
-static GtkTargetEntry bar_pane_exif_drop_types[] = {
+// @todo Use std::array
+constexpr GtkTargetEntry bar_pane_exif_drop_types[] = {
 	{ const_cast<gchar *>(TARGET_APP_EXIF_ENTRY_STRING), GTK_TARGET_SAME_APP, TARGET_APP_EXIF_ENTRY },
 	{ const_cast<gchar *>("text/plain"), 0, TARGET_TEXT_PLAIN }
 };
-static gint n_exif_entry_drop_types = 2;
+constexpr gint n_exif_entry_drop_types = 2;
 
 
-static void bar_pane_exif_entry_dnd_get(GtkWidget *entry, GdkDragContext *,
+void bar_pane_exif_entry_dnd_get(GtkWidget *entry, GdkDragContext *,
 				     GtkSelectionData *selection_data, guint info,
 				     guint, gpointer)
 {
@@ -371,13 +394,14 @@ static void bar_pane_exif_entry_dnd_get(GtkWidget *entry, GdkDragContext *,
 
 }
 
-static void bar_pane_exif_dnd_receive(GtkWidget *pane, GdkDragContext *,
+void bar_pane_exif_dnd_receive(GtkWidget *pane, GdkDragContext *,
 					  gint x, gint y,
 					  GtkSelectionData *selection_data, guint info,
 					  guint, gpointer)
 {
 	PaneExifData *ped;
-	GList *work, *list;
+	GList *work;
+	GList *list;
 	gint pos;
 	GtkWidget *new_entry = nullptr;
 
@@ -403,7 +427,8 @@ static void bar_pane_exif_dnd_receive(GtkWidget *pane, GdkDragContext *,
 	pos = 0;
 	while (work)
 		{
-		gint nx, ny;
+		gint nx;
+		gint ny;
 		auto entry = static_cast<GtkWidget *>(work->data);
 		GtkAllocation allocation;
 		work = work->next;
@@ -422,7 +447,7 @@ static void bar_pane_exif_dnd_receive(GtkWidget *pane, GdkDragContext *,
 	gtk_box_reorder_child(GTK_BOX(ped->vbox), new_entry, pos);
 }
 
-static void bar_pane_exif_entry_dnd_begin(GtkWidget *entry, GdkDragContext *context, gpointer)
+void bar_pane_exif_entry_dnd_begin(GtkWidget *entry, GdkDragContext *context, gpointer)
 {
 	auto ee = static_cast<ExifEntry *>(g_object_get_data(G_OBJECT(entry), "entry_data"));
 
@@ -430,11 +455,11 @@ static void bar_pane_exif_entry_dnd_begin(GtkWidget *entry, GdkDragContext *cont
 	dnd_set_drag_label(entry, context, ee->key);
 }
 
-static void bar_pane_exif_entry_dnd_end(GtkWidget *, GdkDragContext *, gpointer)
+void bar_pane_exif_entry_dnd_end(GtkWidget *, GdkDragContext *, gpointer)
 {
 }
 
-static void bar_pane_exif_entry_dnd_init(GtkWidget *entry)
+void bar_pane_exif_entry_dnd_init(GtkWidget *entry)
 {
 	auto ee = static_cast<ExifEntry *>(g_object_get_data(G_OBJECT(entry), "entry_data"));
 
@@ -450,7 +475,7 @@ static void bar_pane_exif_entry_dnd_init(GtkWidget *entry)
 			 G_CALLBACK(bar_pane_exif_entry_dnd_end), ee);
 }
 
-static void bar_pane_exif_dnd_init(GtkWidget *pane)
+void bar_pane_exif_dnd_init(GtkWidget *pane)
 {
 	gtk_drag_dest_set(pane,
 			  static_cast<GtkDestDefaults>(GTK_DEST_DEFAULT_MOTION | GTK_DEST_DEFAULT_HIGHLIGHT | GTK_DEST_DEFAULT_DROP),
@@ -460,24 +485,24 @@ static void bar_pane_exif_dnd_init(GtkWidget *pane)
 			 G_CALLBACK(bar_pane_exif_dnd_receive), NULL);
 }
 
-static void bar_pane_exif_edit_close_cb(GtkWidget *, gpointer data)
+void bar_pane_exif_edit_close_cb(GtkWidget *, gpointer data)
 {
 	auto gd = static_cast<GenericDialog *>(data);
 	generic_dialog_close(gd);
 }
 
-static void bar_pane_exif_edit_destroy_cb(GtkWidget *, gpointer data)
+void bar_pane_exif_edit_destroy_cb(GtkWidget *, gpointer data)
 {
 	auto cdd = static_cast<ConfDialogData *>(data);
 	g_signal_handlers_disconnect_by_func(cdd->widget, (gpointer)(bar_pane_exif_edit_close_cb), cdd->gd);
 	g_free(cdd);
 }
 
-static void bar_pane_exif_edit_cancel_cb(GenericDialog *, gpointer)
+void bar_pane_exif_edit_cancel_cb(GenericDialog *, gpointer)
 {
 }
 
-static void bar_pane_exif_edit_ok_cb(GenericDialog *, gpointer data)
+void bar_pane_exif_edit_ok_cb(GenericDialog *, gpointer data)
 {
 	auto cdd = static_cast<ConfDialogData *>(data);
 
@@ -533,7 +558,7 @@ static void bar_pane_exif_edit_ok_cb(GenericDialog *, gpointer data)
 		}
 }
 
-static void bar_pane_exif_conf_dialog(GtkWidget *widget)
+void bar_pane_exif_conf_dialog(GtkWidget *widget)
 {
 	ConfDialogData *cdd;
 	GenericDialog *gd;
@@ -591,25 +616,25 @@ static void bar_pane_exif_conf_dialog(GtkWidget *widget)
 	gtk_widget_show(gd->dialog);
 }
 
-static void bar_pane_exif_conf_dialog_cb(GtkWidget *, gpointer data)
+void bar_pane_exif_conf_dialog_cb(GtkWidget *, gpointer data)
 {
 	auto widget = static_cast<GtkWidget *>(data);
 	bar_pane_exif_conf_dialog(widget);
 }
 
-static void bar_pane_exif_delete_entry_cb(GtkWidget *, gpointer data)
+void bar_pane_exif_delete_entry_cb(GtkWidget *, gpointer data)
 {
 	auto entry = static_cast<GtkWidget *>(data);
-	g_object_unref(entry);
+	gtk_container_remove(GTK_CONTAINER(gtk_widget_get_parent(entry)), entry);
 }
 
-#ifdef HAVE_GTK4
-static void bar_pane_exif_copy_entry_cb(GtkWidget *, gpointer data)
+#if HAVE_GTK4
+void bar_pane_exif_copy_entry_cb(GtkWidget *, gpointer data)
 {
 /* @FIXME GTK4 stub */
 }
 #else
-static void bar_pane_exif_copy_entry_cb(GtkWidget *, gpointer data)
+void bar_pane_exif_copy_entry_cb(GtkWidget *, gpointer data)
 {
 	auto widget = static_cast<GtkWidget *>(data);
 	GtkClipboard *clipboard;
@@ -623,14 +648,14 @@ static void bar_pane_exif_copy_entry_cb(GtkWidget *, gpointer data)
 }
 #endif
 
-static void bar_pane_exif_toggle_show_all_cb(GtkWidget *, gpointer data)
+void bar_pane_exif_toggle_show_all_cb(GtkWidget *, gpointer data)
 {
 	auto ped = static_cast<PaneExifData *>(data);
 	ped->show_all = !ped->show_all;
 	bar_pane_exif_update(ped);
 }
 
-static void bar_pane_exif_menu_popup(GtkWidget *widget, PaneExifData *ped)
+void bar_pane_exif_menu_popup(GtkWidget *widget, PaneExifData *ped)
 {
 	GtkWidget *menu;
 	/* the widget can be either ExifEntry (for editing) or Pane (for new entry)
@@ -662,7 +687,7 @@ static void bar_pane_exif_menu_popup(GtkWidget *widget, PaneExifData *ped)
 	gtk_menu_popup_at_pointer(GTK_MENU(menu), nullptr);
 }
 
-static gboolean bar_pane_exif_menu_cb(GtkWidget *widget, GdkEventButton *bevent, gpointer data)
+gboolean bar_pane_exif_menu_cb(GtkWidget *widget, GdkEventButton *bevent, gpointer data)
 {
 	auto ped = static_cast<PaneExifData *>(data);
 	if (bevent->button == MOUSE_BUTTON_RIGHT)
@@ -673,14 +698,14 @@ static gboolean bar_pane_exif_menu_cb(GtkWidget *widget, GdkEventButton *bevent,
 	return FALSE;
 }
 
-#ifdef HAVE_GTK4
-static gboolean bar_pane_exif_copy_cb(GtkWidget *widget, GdkEventButton *bevent, gpointer)
+#if HAVE_GTK4
+gboolean bar_pane_exif_copy_cb(GtkWidget *widget, GdkEventButton *bevent, gpointer)
 {
 /* @FIXME GTK4 stub */
 	return FALSE;
 }
 #else
-static gboolean bar_pane_exif_copy_cb(GtkWidget *widget, GdkEventButton *bevent, gpointer)
+gboolean bar_pane_exif_copy_cb(GtkWidget *widget, GdkEventButton *bevent, gpointer)
 {
 	const gchar *value;
 	GtkClipboard *clipboard;
@@ -700,7 +725,7 @@ static gboolean bar_pane_exif_copy_cb(GtkWidget *widget, GdkEventButton *bevent,
 }
 #endif
 
-static void bar_pane_exif_entry_write_config(GtkWidget *entry, GString *outstr, gint indent)
+void bar_pane_exif_entry_write_config(GtkWidget *entry, GString *outstr, gint indent)
 {
 	auto ee = static_cast<ExifEntry *>(g_object_get_data(G_OBJECT(entry), "entry_data"));
 	if (!ee) return;
@@ -713,10 +738,11 @@ static void bar_pane_exif_entry_write_config(GtkWidget *entry, GString *outstr,
 	WRITE_STRING("/>");
 }
 
-static void bar_pane_exif_write_config(GtkWidget *pane, GString *outstr, gint indent)
+void bar_pane_exif_write_config(GtkWidget *pane, GString *outstr, gint indent)
 {
 	PaneExifData *ped;
-	GList *work, *list;
+	GList *work;
+	GList *list;
 
 	ped = static_cast<PaneExifData *>(g_object_get_data(G_OBJECT(pane), "pane_data"));
 	if (!ped) return;
@@ -743,6 +769,77 @@ static void bar_pane_exif_write_config(GtkWidget *pane, GString *outstr, gint in
 	WRITE_NL(); WRITE_STRING("</pane_exif>");
 }
 
+void bar_pane_exif_destroy(GtkWidget *, gpointer data)
+{
+	auto ped = static_cast<PaneExifData *>(data);
+
+	file_data_unregister_notify_func(bar_pane_exif_notify_cb, ped);
+	g_object_unref(ped->size_group);
+	file_data_unref(ped->fd);
+	g_free(ped->pane.id);
+	g_free(ped);
+}
+
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wunused-function"
+void bar_pane_exif_size_request_unused(GtkWidget *, GtkRequisition *requisition, gpointer data)
+{
+	auto *ped = static_cast<PaneExifData *>(data);
+	if (requisition->height < ped->min_height)
+		{
+		requisition->height = ped->min_height;
+		}
+}
+#pragma GCC diagnostic pop
+
+void bar_pane_exif_size_allocate(GtkWidget *, GtkAllocation *alloc, gpointer data)
+{
+	auto ped = static_cast<PaneExifData *>(data);
+	ped->min_height = alloc->height;
+	gtk_widget_set_size_request(ped->widget, -1, ped->min_height);
+}
+
+GtkWidget *bar_pane_exif_new(const gchar *id, const gchar *title, gboolean expanded, gboolean show_all)
+{
+	PaneExifData *ped;
+
+	ped = g_new0(PaneExifData, 1);
+
+	ped->pane.pane_set_fd = bar_pane_exif_set_fd;
+	ped->pane.pane_write_config = bar_pane_exif_write_config;
+	ped->pane.pane_event = bar_pane_exif_event;
+	ped->pane.title = bar_pane_expander_title(title);
+	ped->pane.id = g_strdup(id);
+	ped->pane.expanded = expanded;
+	ped->pane.type = PANE_EXIF;
+	ped->show_all = show_all;
+
+	ped->size_group = gtk_size_group_new(GTK_SIZE_GROUP_HORIZONTAL);
+	ped->widget = gtk_event_box_new();
+	ped->vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, PREF_PAD_GAP);
+	gq_gtk_container_add(GTK_WIDGET(ped->widget), ped->vbox);
+	gtk_widget_show(ped->vbox);
+
+	ped->min_height = MIN_HEIGHT;
+	g_object_set_data(G_OBJECT(ped->widget), "pane_data", ped);
+	g_signal_connect_after(G_OBJECT(ped->widget), "destroy",
+			       G_CALLBACK(bar_pane_exif_destroy), ped);
+	gtk_widget_set_size_request(ped->widget, -1, ped->min_height);
+	g_signal_connect(G_OBJECT(ped->widget), "size-allocate",
+			 G_CALLBACK(bar_pane_exif_size_allocate), ped);
+
+	bar_pane_exif_dnd_init(ped->widget);
+	g_signal_connect(ped->widget, "button_release_event", G_CALLBACK(bar_pane_exif_menu_cb), ped);
+
+	file_data_register_notify_func(bar_pane_exif_notify_cb, ped, NOTIFY_PRIORITY_LOW);
+
+	gtk_widget_show(ped->widget);
+
+	return ped->widget;
+}
+
+} // namespace
+
 GList * bar_pane_exif_list()
 {
 	PaneExifData *ped;
@@ -792,75 +889,6 @@ void bar_pane_exif_close_unused(GtkWidget *widget)
 }
 #pragma GCC diagnostic pop
 
-static void bar_pane_exif_destroy(GtkWidget *, gpointer data)
-{
-	auto ped = static_cast<PaneExifData *>(data);
-
-	file_data_unregister_notify_func(bar_pane_exif_notify_cb, ped);
-	g_object_unref(ped->size_group);
-	file_data_unref(ped->fd);
-	g_free(ped->pane.id);
-	g_free(ped);
-}
-
-#pragma GCC diagnostic push
-#pragma GCC diagnostic ignored "-Wunused-function"
-static void bar_pane_exif_size_request_unused(GtkWidget *, GtkRequisition *requisition, gpointer data)
-{
-	PaneExifData *ped = static_cast<PaneExifData *>(data);
-	if (requisition->height < ped->min_height)
-		{
-		requisition->height = ped->min_height;
-		}
-}
-#pragma GCC diagnostic pop
-
-static void bar_pane_exif_size_allocate(GtkWidget *, GtkAllocation *alloc, gpointer data)
-{
-	auto ped = static_cast<PaneExifData *>(data);
-	ped->min_height = alloc->height;
-	gtk_widget_set_size_request(ped->widget, -1, ped->min_height);
-}
-
-static GtkWidget *bar_pane_exif_new(const gchar *id, const gchar *title, gboolean expanded, gboolean show_all)
-{
-	PaneExifData *ped;
-
-	ped = g_new0(PaneExifData, 1);
-
-	ped->pane.pane_set_fd = bar_pane_exif_set_fd;
-	ped->pane.pane_write_config = bar_pane_exif_write_config;
-	ped->pane.pane_event = bar_pane_exif_event;
-	ped->pane.title = bar_pane_expander_title(title);
-	ped->pane.id = g_strdup(id);
-	ped->pane.expanded = expanded;
-	ped->pane.type = PANE_EXIF;
-	ped->show_all = show_all;
-
-	ped->size_group = gtk_size_group_new(GTK_SIZE_GROUP_HORIZONTAL);
-	ped->widget = gtk_event_box_new();
-	ped->vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, PREF_PAD_GAP);
-	gq_gtk_container_add(GTK_WIDGET(ped->widget), ped->vbox);
-	gtk_widget_show(ped->vbox);
-
-	ped->min_height = MIN_HEIGHT;
-	g_object_set_data(G_OBJECT(ped->widget), "pane_data", ped);
-	g_signal_connect_after(G_OBJECT(ped->widget), "destroy",
-			       G_CALLBACK(bar_pane_exif_destroy), ped);
-	gtk_widget_set_size_request(ped->widget, -1, ped->min_height);
-	g_signal_connect(G_OBJECT(ped->widget), "size-allocate",
-			 G_CALLBACK(bar_pane_exif_size_allocate), ped);
-
-	bar_pane_exif_dnd_init(ped->widget);
-	g_signal_connect(ped->widget, "button_release_event", G_CALLBACK(bar_pane_exif_menu_cb), ped);
-
-	file_data_register_notify_func(bar_pane_exif_notify_cb, ped, NOTIFY_PRIORITY_LOW);
-
-	gtk_widget_show(ped->widget);
-
-	return ped->widget;
-}
-
 GtkWidget *bar_pane_exif_new_from_config(const gchar **attribute_names, const gchar **attribute_values)
 {
 	gchar *title = nullptr;
