@@ -24,7 +24,9 @@
 #include <cstring>
 
 #include <cairo.h>
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
 #include <champlain-gtk/champlain-gtk.h>
+G_GNUC_END_IGNORE_DEPRECATIONS
 #include <champlain/champlain.h>
 #include <clutter-gtk/clutter-gtk.h>
 #include <clutter/clutter.h>
@@ -51,12 +53,17 @@
 #include "ui-utildlg.h"
 #include "uri-utils.h"
 
+namespace
+{
+
+constexpr gint THUMB_SIZE = 100;
+constexpr int DIRECTION_SIZE = 300;
+
+} // namespace
+
 #define MARKER_COLOUR 0x00, 0x00, 0xff, 0xff
 #define TEXT_COLOUR 0x00, 0x00, 0x00, 0xff
 #define THUMB_COLOUR 0xff, 0xff, 0xff, 0xff
-#define THUMB_SIZE 100
-
-#define DIRECTION_SIZE 300
 
 /*
  *-------------------------------------------------------------------
@@ -469,7 +476,7 @@ static gboolean bar_pane_gps_create_markers_cb(gpointer data)
 		longitude = metadata_read_GPS_coord(fd, "Xmp.exif.GPSLongitude", 0);
 		compass = metadata_read_GPS_direction(fd, "Xmp.exif.GPSImgDirection", 1000);
 
-		if (!(latitude == 0 && longitude == 0))
+		if (latitude != 0 || longitude != 0)
 			{
 			pgd->num_added++;
 
