@@ -19,15 +19,27 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#include "main.h"
 #include "bar-histogram.h"
 
+#include <cairo.h>
+#include <gdk-pixbuf/gdk-pixbuf.h>
+#include <gdk/gdk.h>
+#include <glib-object.h>
+
+#include <config.h>
+
 #include "bar.h"
+#include "compat.h"
+#include "debug.h"
 #include "filedata.h"
+#include "histogram.h"
+#include "intl.h"
+#include "rcfile.h"
+#include "typedefs.h"
 #include "ui-menu.h"
 #include "ui-misc.h"
-#include "histogram.h"
-#include "rcfile.h"
+
+struct HistMap;
 
 /*
  *-------------------------------------------------------------------
@@ -295,7 +307,7 @@ static GtkWidget *bar_pane_histogram_new(const gchar *id, const gchar *title, gi
 	gtk_widget_add_events(phd->drawing_area, GDK_BUTTON_PRESS_MASK);
 
 
-#ifdef HAVE_GTK4
+#if HAVE_GTK4
 	gesture = gtk_gesture_click_new();
 	gtk_widget_add_controller(phd->drawing_area, GTK_EVENT_CONTROLLER(gesture));
 #else
