@@ -19,17 +19,38 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#include "main.h"
 #include "bar.h"
 
-#include "bar-histogram.h"
+#include <cstring>
+
+#include <glib-object.h>
+#include <pango/pango.h>
+
+#include <config.h>
+
+#include "compat.h"
+#include "debug.h"
 #include "filedata.h"
+#include "intl.h"
 #include "layout.h"
+#include "main-defines.h"
 #include "metadata.h"
 #include "rcfile.h"
+#include "typedefs.h"
 #include "ui-menu.h"
 #include "ui-misc.h"
 
+
+namespace
+{
+
+void remove_child_from_parent(gpointer data)
+{
+	gtk_container_remove(GTK_CONTAINER(gtk_widget_get_parent(GTK_WIDGET(data))), GTK_WIDGET(data));
+}
+
+}
+
 struct KnownPanes
 {
 	PaneType type;
@@ -167,8 +188,7 @@ static const gchar default_config_copyright[] =
 "    </layout>"
 "</gq>";
 
-#ifdef HAVE_LIBCHAMPLAIN
-#ifdef HAVE_LIBCHAMPLAIN_GTK
+#if HAVE_LIBCHAMPLAIN && HAVE_LIBCHAMPLAIN_GTK
 static const gchar default_config_gps[] =
 "<gq>"
 "    <layout id = '_current_'>"
@@ -182,7 +202,6 @@ static const gchar default_config_gps[] =
 "    </layout>"
 "</gq>";
 #endif
-#endif
 
 static const KnownPanes known_panes[] = {
 /* default sidebar */
@@ -197,10 +216,8 @@ static const KnownPanes known_panes[] = {
 	{PANE_EXIF,		"file_info",	N_("File info"),	default_config_file_info},
 	{PANE_EXIF,		"location",	N_("Location and GPS"),	default_config_location},
 	{PANE_EXIF,		"copyright",	N_("Copyright"),	default_config_copyright},
-#ifdef HAVE_LIBCHAMPLAIN
-#ifdef HAVE_LIBCHAMPLAIN_GTK
+#if HAVE_LIBCHAMPLAIN && HAVE_LIBCHAMPLAIN_GTK
 	{PANE_GPS,		"gps",	N_("GPS Map"),	default_config_gps},
-#endif
 #endif
 	{PANE_UNDEF,		nullptr,		nullptr,			nullptr}
 };
@@ -275,7 +292,7 @@ static void height_spin_key_press_cb(GtkEventControllerKey *, gint keyval, guint
 {
 	if ((keyval == GDK_KEY_Return || keyval == GDK_KEY_Escape))
 		{
-		g_object_unref(GTK_WIDGET(data));
+		gq_gtk_widget_destroy(GTK_WIDGET(data));
 		}
 }
 
@@ -291,8 +308,10 @@ static void bar_expander_height_cb(GtkWidget *, gpointer data)
 	GtkWidget *window;
 	GtkWidget *data_box;
 	GList *list;
-	gint x, y;
-	gint w, h;
+	gint x;
+	gint y;
+	gint w;
+	gint h;
 	GdkDisplay *display;
 	GdkSeat *seat;
 	GdkDevice *device;
@@ -306,7 +325,7 @@ static void bar_expander_height_cb(GtkWidget *, gpointer data)
 	list = gtk_container_get_children(GTK_CONTAINER(expander));
 	data_box = static_cast<GtkWidget *>(list->data);
 
-#ifdef HAVE_GTK4
+#if HAVE_GTK4
 	window = gtk_window_new();
 #else
 	window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
@@ -339,7 +358,7 @@ static void bar_expander_height_cb(GtkWidget *, gpointer data)
 static void bar_expander_delete_cb(GtkWidget *, gpointer data)
 {
 	auto expander = static_cast<GtkWidget *>(data);
-	g_object_unref(expander);
+	gtk_container_remove(GTK_CONTAINER(gtk_widget_get_parent(expander)), expander);
 }
 
 static void bar_expander_add_cb(GtkWidget *widget, gpointer)
@@ -518,7 +537,8 @@ void bar_notify_selection(GtkWidget *bar, gint count)
 gboolean bar_event(GtkWidget *bar, GdkEvent *event)
 {
 	BarData *bd;
-	GList *list, *work;
+	GList *list;
+	GList *work;
 	gboolean ret = FALSE;
 
 	bd = static_cast<BarData *>(g_object_get_data(G_OBJECT(bar), "bar_data"));
@@ -547,7 +567,8 @@ gboolean bar_event(GtkWidget *bar, GdkEvent *event)
 GtkWidget *bar_find_pane_by_id(GtkWidget *bar, PaneType type, const gchar *id)
 {
 	BarData *bd;
-	GList *list, *work;
+	GList *list;
+	GList *work;
 	GtkWidget *ret = nullptr;
 
 	if (!id || !id[0]) return nullptr;
@@ -585,13 +606,14 @@ void bar_clear(GtkWidget *bar)
 
 	list = gtk_container_get_children(GTK_CONTAINER(bd->vbox));
 
-	g_list_free_full(list, reinterpret_cast<GDestroyNotify>(g_object_unref));
+	g_list_free_full(list, reinterpret_cast<GDestroyNotify>(remove_child_from_parent));
 }
 
 void bar_write_config(GtkWidget *bar, GString *outstr, gint indent)
 {
 	BarData *bd;
-	GList *list, *work;
+	GList *list;
+	GList *work;
 
 	if (!bar) return;
 
@@ -725,7 +747,7 @@ static void bar_destroy(GtkWidget *, gpointer data)
 	g_free(bd);
 }
 
-#ifdef HAVE_LIBCHAMPLAIN_GTK
+#if HAVE_LIBCHAMPLAIN_GTK
 /**
    @FIXME this is an ugly hack that works around this bug:
    https://bugzilla.gnome.org/show_bug.cgi?id=590692
@@ -800,7 +822,7 @@ GtkWidget *bar_new(LayoutWindow *lw)
 					     _("Add Pane"), G_CALLBACK(bar_menu_add_cb), bd);
 	gtk_widget_show(add_box);
 
-#ifdef HAVE_LIBCHAMPLAIN_GTK
+#if HAVE_LIBCHAMPLAIN_GTK
 	g_signal_connect(G_OBJECT(gtk_bin_get_child(GTK_BIN(scrolled))), "unrealize", G_CALLBACK(bar_unrealize_clutter_fix_cb), NULL);
 #endif
 
