@@ -19,11 +19,24 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#include "main.h"
 #include "cache-loader.h"
 
+#include <sys/types.h>
+
+#include <cstdio>
+#include <cstring>
+#include <ctime>
+
+#include <gdk-pixbuf/gdk-pixbuf.h>
+#include <glib-object.h>
+
+#include "cache.h"
 #include "filedata.h"
+#include "image-load.h"
 #include "metadata.h"
+#include "options.h"
+#include "similar.h"
+#include "typedefs.h"
 #include "ui-fileops.h"
 
 
