@@ -49,6 +49,12 @@
 #include "ui-utildlg.h"
 #include "window.h"
 
+namespace
+{
+
+constexpr gint PURGE_DIALOG_WIDTH = 400;
+
+} // namespace
 
 struct CMData
 {
@@ -65,10 +71,6 @@ struct CMData
 	gboolean remote;
 };
 
-enum {
-	PURGE_DIALOG_WIDTH = 400
-};
-
 /*
  *-----------------------------------------------------------------------------
  * Command line cache maintenance program functions *-----------------------------------------------------------------------------
