@@ -22,9 +22,11 @@
 #ifndef CACHE_H
 #define CACHE_H
 
+#include <sys/types.h>
 
-#include "similar.h"
+#include <glib.h>
 
+struct ImageSimilarityData;
 
 #define GQ_CACHE_THUMB		"thumbnails"
 #define GQ_CACHE_METADATA    	"metadata"
@@ -70,7 +72,7 @@ gboolean cache_sim_data_save(CacheData *cd);
 CacheData *cache_sim_data_load(const gchar *path);
 
 void cache_sim_data_set_dimensions(CacheData *cd, gint w, gint h);
-void cache_sim_data_set_md5sum(CacheData *cd, guchar digest[16]);
+void cache_sim_data_set_md5sum(CacheData *cd, const guchar digest[16]);
 void cache_sim_data_set_similarity(CacheData *cd, ImageSimilarityData *sd);
 gint cache_sim_data_filled(ImageSimilarityData *sd);
 
