@@ -19,15 +19,20 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#include <memory>
-
-#include "main.h"
-#include "collect.h"
 #include "collect-dlg.h"
 
+#include <glib-object.h>
+#include <glib.h>
+#include <gtk/gtk.h>
+
 #include "collect-io.h"
+#include "collect.h"
+#include "compat.h"
+#include "intl.h"
+#include "main-defines.h"
 #include "misc.h"
 #include "ui-fileops.h"
+#include "ui-utildlg.h"
 #include "utilops.h"
 
 enum {
@@ -142,7 +147,7 @@ static void collection_save_or_append_dialog(gint type, CollectionData *cd)
 
 		title = _("Save collection");
 
-		gdlg = file_util_gen_dlg(title, "dlg_collection_save", NULL, FALSE, collection_save_or_load_dialog_close_cb, cd);
+		gdlg = file_util_gen_dlg(title, "dlg_collection_save", nullptr, FALSE, collection_save_or_load_dialog_close_cb, cd);
 
 		generic_dialog_add_message(GENERIC_DIALOG(gdlg), nullptr, title, _("Existing collections:"), FALSE);
 		generic_dialog_add_button(gdlg, GQ_ICON_SAVE, _("Save"), collection_save_cb, TRUE);
@@ -175,7 +180,7 @@ static void collection_save_or_append_dialog(gint type, CollectionData *cd)
 
 		gq_gtk_box_pack_start(GTK_BOX(gdlg->vbox), scrolled, TRUE,TRUE, 0);
 
-		save_as_label = gtk_label_new("Save collection as:");
+		save_as_label = gtk_label_new(_("Save collection as:"));
 		gq_gtk_box_pack_start(GTK_BOX(gdlg->vbox), save_as_label, FALSE,FALSE, 0);
 		gtk_label_set_xalign(GTK_LABEL(save_as_label), 0.0);
 		gtk_widget_show(save_as_label);
