@@ -19,21 +19,35 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#include "main.h"
 #include "collect-io.h"
 
+#include <cstdio>
+#include <cstring>
+
+#include <gdk-pixbuf/gdk-pixbuf.h>
+#include <gdk/gdk.h>
+#include <glib-object.h>
+
+#include <config.h>
+
 #include "collect.h"
+#include "debug.h"
 #include "filedata.h"
+#include "intl.h"
 #include "layout-util.h"
+#include "main-defines.h"
+#include "options.h"
 #include "secure-save.h"
 #include "thumb.h"
 #include "ui-fileops.h"
 
 #define GQ_COLLECTION_MARKER "#" GQ_APPNAME
 
-#define GQ_COLLECTION_FAIL_MIN     300
-#define GQ_COLLECTION_FAIL_PERCENT 98
-#define GQ_COLLECTION_READ_BUFSIZE 4096
+enum {
+	GQ_COLLECTION_FAIL_MIN =     300,
+	GQ_COLLECTION_FAIL_PERCENT = 98,
+	GQ_COLLECTION_READ_BUFSIZE = 4096
+};
 
 struct CollectManagerEntry;
 
@@ -49,7 +63,10 @@ namespace
 
 gboolean scan_geometry(gchar *buffer, GdkRectangle &window)
 {
-	gint nx, ny, nw, nh;
+	gint nx;
+	gint ny;
+	gint nw;
+	gint nh;
 
 	if (sscanf(buffer, "%d %d %d %d", &nx, &ny, &nw, &nh) != 4) return FALSE;
 
@@ -194,12 +211,10 @@ static gboolean collection_load_private(CollectionData *cd, const gchar *path, C
 				g_string_append(extended_filename_buffer, buf);
 				continue;
 				}
-			else
-				{
-				/* end of extended filename found */
-				g_string_append_len(extended_filename_buffer, buf, p - buf);
-				reading_extended_filename = FALSE;
-				}
+
+			/* end of extended filename found */
+			g_string_append_len(extended_filename_buffer, buf, p - buf);
+			reading_extended_filename = FALSE;
 			}
 
 		if (extended_filename_buffer->len > 0)
@@ -477,8 +492,10 @@ gboolean collection_load_only_geometry(CollectionData *cd, const gchar *path)
  *-------------------------------------------------------------------
  */
 
-#define COLLECT_MANAGER_ACTIONS_PER_IDLE 1000
-#define COLLECT_MANAGER_FLUSH_DELAY      10000
+enum {
+	COLLECT_MANAGER_ACTIONS_PER_IDLE = 1000,
+	COLLECT_MANAGER_FLUSH_DELAY =      10000
+};
 
 struct CollectManagerEntry
 {
