@@ -22,6 +22,9 @@
 #ifndef COLOR_MAN_H
 #define COLOR_MAN_H
 
+#include <gdk-pixbuf/gdk-pixbuf.h>
+#include <glib.h>
+
 struct FileData;
 struct ImageWindow;
 
