@@ -21,6 +21,9 @@
 #ifndef COMPAT_H
 #define COMPAT_H
 
+#include <gtk/gtk.h>
+
+#include <config.h>
 
 /* Some systems (BSD,MacOsX,HP-UX,...) define MAP_ANON and not MAP_ANONYMOUS */
 #if defined(MAP_ANON) && !defined(MAP_ANONYMOUS)
@@ -29,7 +32,7 @@
 #define	MAP_ANON	MAP_ANONYMOUS
 #endif
 
-#ifdef HAVE_GTK4
+#if HAVE_GTK4
 	#define gq_gtk_box_pack_end(box, child, expand, fill, padding) gtk_box_append(box, child)
 	#define gq_gtk_box_pack_start(box, child, expand, fill, padding) gtk_box_prepend(box, child)
 	#define gq_gtk_frame_set_shadow_type(frame, type) ;
