@@ -18,19 +18,30 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#include "main.h"
 #include "debug.h"
 
-#include "filedata.h"
-#include "logwindow.h"
-#include "misc.h"
-#include "ui-fileops.h"
+#include <regex.h>
+#include <sys/time.h>
 
-#ifdef HAVE_EXECINFO_H
-#include <execinfo.h>
+#include <cstdarg>
+#include <cstdio>
+#include <cstdlib>
+#include <cstring>
+
+#include <config.h>
+
+#if HAVE_EXECINFO_H
+#  include <execinfo.h>
 #endif
 
-#include <regex.h>
+#include "filedata.h"
+#include "intl.h"
+#include "logwindow.h"
+#include "main-defines.h"
+#include "main.h"
+#include "misc.h"
+#include "options.h"
+#include "ui-fileops.h"
 
 /*
  * Logging functions
@@ -84,7 +95,8 @@ void log_domain_print_message(const gchar *domain, gchar *buf)
 {
 	gchar *buf_nl;
 	regex_t regex;
-	gint ret_comp, ret_exec;
+	gint ret_comp;
+	gint ret_exec;
 
 	buf_nl = g_strconcat(buf, "\n", NULL);
 
@@ -254,7 +266,7 @@ gchar *get_regexp()
 	return g_strdup(regexp);
 }
 
-#ifdef HAVE_EXECINFO_H
+#if HAVE_EXECINFO_H
 /**
  * @brief Backtrace of geeqie files
  * @param file
