@@ -19,20 +19,37 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#include "main.h"
 #include "desktop-file.h"
 
+#include <unistd.h>
+
+#include <cstring>
+
+#include <gdk/gdk.h>
+#include <glib-object.h>
+#include <glib.h>
+#include <gtk/gtk.h>
+
+#include "compat.h"
+#include "debug.h"
 #include "editors.h"
+#include "intl.h"
 #include "layout-util.h"
+#include "main-defines.h"
+#include "main.h"
 #include "misc.h"
+#include "options.h"
 #include "pixbuf-util.h"
 #include "ui-fileops.h"
 #include "ui-misc.h"
+#include "ui-utildlg.h"
 #include "utilops.h"
 #include "window.h"
 
-#define CONFIG_WINDOW_DEF_WIDTH		700
-#define CONFIG_WINDOW_DEF_HEIGHT	400
+enum {
+	CONFIG_WINDOW_DEF_WIDTH =		700,
+	CONFIG_WINDOW_DEF_HEIGHT =	400
+};
 
 
 
@@ -68,7 +85,8 @@ static gboolean editor_window_save(EditorWindow *ew)
 	gchar *dir;
 	gchar *path;
 	gchar *text;
-	GtkTextIter start, end;
+	GtkTextIter start;
+	GtkTextIter end;
 	GError *error = nullptr;
 	gboolean ret = TRUE;
 	const gchar *name = gq_gtk_entry_get_text(GTK_ENTRY(ew->entry));
@@ -342,7 +360,7 @@ static void editor_list_window_delete_cb(GtkWidget *, gpointer data)
 					    nullptr, TRUE,
 					    editor_list_window_delete_dlg_cancel, ewdl);
 
-		generic_dialog_add_button(ewl->gd, GQ_ICON_DELETE, "Delete", editor_list_window_delete_dlg_ok_cb, TRUE);
+		generic_dialog_add_button(ewl->gd, GQ_ICON_DELETE, _("Delete"), editor_list_window_delete_dlg_ok_cb, TRUE);
 
 		text = g_strdup_printf(_("About to delete the file:\n %s"), path);
 		generic_dialog_add_message(ewl->gd, GQ_ICON_DIALOG_QUESTION,
@@ -410,7 +428,8 @@ static gint editor_list_window_sort_cb(GtkTreeModel *model, GtkTreeIter *a, GtkT
 {
 	gint n = GPOINTER_TO_INT(data);
 	gint ret = 0;
-	gboolean bool1, bool2;
+	gboolean bool1;
+	gboolean bool2;
 
 	switch (n)
 		{
@@ -419,7 +438,8 @@ static gint editor_list_window_sort_cb(GtkTreeModel *model, GtkTreeIter *a, GtkT
 		case DESKTOP_FILE_COLUMN_PATH:
 		case DESKTOP_FILE_COLUMN_HIDDEN:
 			{
-			gchar *s1, *s2;
+			gchar *s1;
+			gchar *s2;
 
 			gtk_tree_model_get(model, a, n, &s1, -1);
 			gtk_tree_model_get(model, b, n, &s2, -1);
@@ -580,7 +600,7 @@ static void editor_list_window_create()
 	gtk_widget_show(button);
 	ewl->edit_button = button;
 
-	button = pref_button_new(nullptr, GQ_ICON_DELETE, "Delete",
+	button = pref_button_new(nullptr, GQ_ICON_DELETE, _("Delete"),
 				 G_CALLBACK(editor_list_window_delete_cb), ewl);
 	gq_gtk_container_add(GTK_WIDGET(hbox), button);
 	gtk_widget_set_can_default(button, TRUE);
