@@ -22,6 +22,10 @@
 #ifndef __EXIF_H
 #define __EXIF_H
 
+#include <glib.h>
+
+#include "typedefs.h"
+
 struct ExifData;
 struct ExifItem;
 struct FileData;
@@ -167,7 +171,7 @@ void exif_set_image_comment(FileData* fd, const gchar* comment);
 
 /*raw support */
 guchar *exif_get_preview(ExifData *exif, guint *data_len, gint requested_width, gint requested_height);
-void exif_free_preview(guchar *buf);
+void exif_free_preview(const guchar *buf);
 
 gchar *metadata_file_info(FileData *fd, const gchar *key, MetadataFormat format);
 gchar *metadata_lua_info(FileData *fd, const gchar *key, MetadataFormat format);
