@@ -269,23 +269,21 @@ std::vector<ScreenData> fullscreen_prefs_list()
 {
 	std::vector<ScreenData> list;
 	GdkDisplay *display;
-	GdkScreen *screen;
 	gint monitors;
+	const gchar *name;
 
 	display = gdk_display_get_default();
-	screen = gdk_display_get_default_screen(display);
 	monitors = gdk_display_get_n_monitors(display);
+	name = gdk_display_get_name(display);
 
 	for (gint j = -1; j < monitors; j++)
 		{
 		GdkRectangle rect;
-		gchar *name;
 		gchar *subname;
 
-		name = gdk_screen_make_display_name(screen);
-
 		if (j < 0)
 			{
+			GdkScreen *screen = gdk_display_get_default_screen(display);
 			rect = get_screen_default_geometry(screen);
 			subname = g_strdup(_("Full size"));
 			}
@@ -310,7 +308,6 @@ std::vector<ScreenData> fullscreen_prefs_list()
 
 		list.push_back(sd);
 
-		g_free(name);
 		g_free(subname);
 		}
 
@@ -391,7 +388,9 @@ gint fullscreen_prefs_find_screen_for_widget_unused(GtkWidget *widget)
 	if (!widget || !gtk_widget_get_window(widget)) return 0;
 
 	screen = gtk_widget_get_screen(widget);
+	G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
 	monitor = gdk_screen_get_monitor_at_window(screen, gtk_widget_get_window(widget));
+	G_GNUC_END_IGNORE_DEPRECATIONS;
 
 	n = 100 + monitor + 1;
 
