@@ -18,30 +18,47 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#include "main.h"
-#include "image-load.h"
 #include "image-load-collection.h"
 
+#include <unistd.h>
+
+#include <cstdio>
+
+#include <gdk-pixbuf/gdk-pixbuf.h>
+#include <glib-object.h>
+#include <glib.h>
+
 #include "cache.h"
 #include "filedata.h"
+#include "image-load.h"
 #include "misc.h"
+#include "options.h"
 #include "ui-fileops.h"
 
-struct ImageLoaderCOLLECTION {
-	ImageLoaderBackendCbAreaUpdated area_updated_cb;
-	ImageLoaderBackendCbSize size_cb;
-	ImageLoaderBackendCbAreaPrepared area_prepared_cb;
+namespace
+{
+
+struct ImageLoaderCOLLECTION : public ImageLoaderBackend
+{
+public:
+	~ImageLoaderCOLLECTION() override;
+
+	void init(AreaUpdatedCb area_updated_cb, SizePreparedCb size_prepared_cb, AreaPreparedCb area_prepared_cb, gpointer data) override;
+	gboolean write(const guchar *buf, gsize &chunk_size, gsize count, GError **error) override;
+	GdkPixbuf *get_pixbuf() override;
+	gchar *get_format_name() override;
+	gchar **get_format_mime_types() override;
+
+private:
+	AreaUpdatedCb area_updated_cb;
 	gpointer data;
+
 	GdkPixbuf *pixbuf;
-	guint requested_width;
-	guint requested_height;
-	gboolean abort;
 };
 
-static gboolean image_loader_collection_load(gpointer loader, const guchar *, gsize, GError **)
+gboolean ImageLoaderCOLLECTION::write(const guchar *, gsize &chunk_size, gsize count, GError **)
 {
-	auto ld = static_cast<ImageLoaderCOLLECTION *>(loader);
-	auto il = static_cast<ImageLoader *>(ld->data);
+	auto il = static_cast<ImageLoader *>(data);
 
 	#define LINE_LENGTH 1000
 
@@ -92,10 +109,10 @@ static gboolean image_loader_collection_load(gpointer loader, const guchar *, gs
 				cmd_line = g_strdup_printf("montage %s -geometry %dx%d+1+1 %s >/dev/null 2>&1", file_names->str, options->thumbnails.max_width, options->thumbnails.max_height, randname);
 
 				runcmd(cmd_line);
-				ld->pixbuf = gdk_pixbuf_new_from_file(randname, nullptr);
-				if (ld->pixbuf)
+				pixbuf = gdk_pixbuf_new_from_file(randname, nullptr);
+				if (pixbuf)
 					{
-					ld->area_updated_cb(loader, 0, 0, gdk_pixbuf_get_width(ld->pixbuf), gdk_pixbuf_get_height(ld->pixbuf), ld->data);
+					area_updated_cb(nullptr, 0, 0, gdk_pixbuf_get_width(pixbuf), gdk_pixbuf_get_height(pixbuf), data);
 					}
 
 				unlink(randname);
@@ -108,72 +125,42 @@ static gboolean image_loader_collection_load(gpointer loader, const guchar *, gs
 			g_string_free(file_names, TRUE);
 			}
 		}
+	chunk_size = count;
 	return ret;
 }
 
-static gpointer image_loader_collection_new(ImageLoaderBackendCbAreaUpdated area_updated_cb, ImageLoaderBackendCbSize size_cb, ImageLoaderBackendCbAreaPrepared area_prepared_cb, gpointer data)
+void ImageLoaderCOLLECTION::init(AreaUpdatedCb area_updated_cb, SizePreparedCb, AreaPreparedCb, gpointer data)
 {
-	auto loader = g_new0(ImageLoaderCOLLECTION, 1);
-	loader->area_updated_cb = area_updated_cb;
-	loader->size_cb = size_cb;
-	loader->area_prepared_cb = area_prepared_cb;
-	loader->data = data;
-	return loader;
+	this->area_updated_cb = area_updated_cb;
+	this->data = data;
 }
 
-static void image_loader_collection_set_size(gpointer loader, int width, int height)
+GdkPixbuf *ImageLoaderCOLLECTION::get_pixbuf()
 {
-	auto ld = static_cast<ImageLoaderCOLLECTION *>(loader);
-	ld->requested_width = width;
-	ld->requested_height = height;
+	return pixbuf;
 }
 
-static GdkPixbuf* image_loader_collection_get_pixbuf(gpointer loader)
-{
-	auto ld = static_cast<ImageLoaderCOLLECTION *>(loader);
-	return ld->pixbuf;
-}
-
-static gchar* image_loader_collection_get_format_name(gpointer)
+gchar *ImageLoaderCOLLECTION::get_format_name()
 {
 	return g_strdup("collection");
 }
-static gchar** image_loader_collection_get_format_mime_types(gpointer)
+
+gchar **ImageLoaderCOLLECTION::get_format_mime_types()
 {
 	static const gchar *mime[] = {"image/png", nullptr};
 	return g_strdupv(const_cast<gchar **>(mime));
 }
 
-static gboolean image_loader_collection_close(gpointer, GError **)
+ImageLoaderCOLLECTION::~ImageLoaderCOLLECTION()
 {
-	return TRUE;
+	if (pixbuf) g_object_unref(pixbuf);
 }
 
-static void image_loader_collection_abort(gpointer loader)
-{
-	auto ld = static_cast<ImageLoaderCOLLECTION *>(loader);
-	ld->abort = TRUE;
-}
+} // namespace
 
-static void image_loader_collection_free(gpointer loader)
+std::unique_ptr<ImageLoaderBackend> get_image_loader_backend_collection()
 {
-	auto ld = static_cast<ImageLoaderCOLLECTION *>(loader);
-	if (ld->pixbuf) g_object_unref(ld->pixbuf);
-	g_free(ld);
-}
-
-void image_loader_backend_set_collection(ImageLoaderBackend *funcs)
-{
-	funcs->loader_new = image_loader_collection_new;
-	funcs->set_size = image_loader_collection_set_size;
-	funcs->load = image_loader_collection_load;
-	funcs->write = nullptr;
-	funcs->get_pixbuf = image_loader_collection_get_pixbuf;
-	funcs->close = image_loader_collection_close;
-	funcs->abort = image_loader_collection_abort;
-	funcs->free = image_loader_collection_free;
-	funcs->get_format_name = image_loader_collection_get_format_name;
-	funcs->get_format_mime_types = image_loader_collection_get_format_mime_types;
+	return std::make_unique<ImageLoaderCOLLECTION>();
 }
 
 /* vim: set shiftwidth=8 softtabstop=0 cindent cinoptions={1s: */
