@@ -21,8 +21,12 @@
 #ifndef IMAGE_LOAD_RAW_H
 #define IMAGE_LOAD_RAW_H
 
+#include <glib.h>
+
+struct ImageLoader;
+
 guchar *libraw_get_preview(ImageLoader *il, guint *data_len);
-void libraw_free_preview(guchar *buf);
+void libraw_free_preview(const guchar *buf);
 
 #endif
 
