@@ -22,6 +22,13 @@
 #ifndef IMAGE_H
 #define IMAGE_H
 
+#include <gdk-pixbuf/gdk-pixbuf.h>
+#include <gdk/gdk.h>
+#include <glib.h>
+#include <gtk/gtk.h>
+
+#include "typedefs.h"
+
 struct CollectInfo;
 struct CollectionData;
 struct FileData;
