@@ -19,26 +19,39 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#include "main.h"
 #include "img-view.h"
 
-#include "collect.h"
+#include <gdk/gdk.h>
+#include <glib-object.h>
+#include <gtk/gtk.h>
+
+#include "archives.h"
 #include "collect-io.h"
+#include "collect.h"
+#include "compat.h"
+#include "debug.h"
 #include "dnd.h"
 #include "editors.h"
 #include "filedata.h"
 #include "fullscreen.h"
-#include "image.h"
 #include "image-load.h"
 #include "image-overlay.h"
+#include "image.h"
+#include "intl.h"
 #include "layout-util.h"
+#include "layout.h"
+#include "main-defines.h"
+#include "main.h"
 #include "menu.h"
 #include "misc.h"
+#include "options.h"
 #include "pixbuf-util.h"
 #include "print.h"
 #include "slideshow.h"
+#include "typedefs.h"
 #include "ui-fileops.h"
 #include "ui-menu.h"
+#include "ui-utildlg.h"
 #include "uri-utils.h"
 #include "utilops.h"
 #include "window.h"
@@ -657,7 +670,7 @@ static void button_cb(ImageWindow *imd, GdkEventButton *event, gpointer data)
 	switch (event->button)
 		{
 		case MOUSE_BUTTON_LEFT:
-	 		if (options->image_l_click_archive && imd->image_fd->format_class == FORMAT_CLASS_ARCHIVE)
+			if (options->image_l_click_archive && imd->image_fd->format_class == FORMAT_CLASS_ARCHIVE)
 				{
 				dest_dir = open_archive(imd->image_fd);
 				if (dest_dir)
@@ -671,7 +684,7 @@ static void button_cb(ImageWindow *imd, GdkEventButton *event, gpointer data)
 					warning_dialog(_("Cannot open archive file"), _("See the Log Window"), GQ_ICON_DIALOG_WARNING, nullptr);
 					}
 				}
-	 		else if (options->image_l_click_video && options->image_l_click_video_editor && imd->image_fd->format_class == FORMAT_CLASS_VIDEO)
+			else if (options->image_l_click_video && options->image_l_click_video_editor && imd->image_fd->format_class == FORMAT_CLASS_VIDEO)
 				{
 				start_editor_from_file(options->image_l_click_video_editor, imd->image_fd);
 				}
@@ -902,7 +915,8 @@ static ViewWindow *real_view_window_new(FileData *fd, GList *list, CollectionDat
 	ViewWindow *vw;
 	GtkAllocation req_size;
 	GdkGeometry geometry;
-	gint w, h;
+	gint w;
+	gint h;
 
 	if (!fd && !list && (!cd || !info)) return nullptr;
 
