@@ -19,9 +19,12 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#include "main.h"
 #include "jpeg-parser.h"
 
+#include <cstring>
+
+#include "debug.h"
+
 gboolean jpeg_segment_find(const guchar *data, guint size,
 			    guchar app_marker, const gchar *magic, guint magic_len,
 			    guint *seg_offset, guint *seg_length)
@@ -65,11 +68,13 @@ enum TiffByteOrder {
 	TIFF_BYTE_ORDER_MOTOROLA
 };
 
-#define TIFF_TIFD_OFFSET_TAG 0
-#define TIFF_TIFD_OFFSET_FORMAT 2
-#define TIFF_TIFD_OFFSET_COUNT 4
-#define TIFF_TIFD_OFFSET_DATA 8
-#define TIFF_TIFD_SIZE 12
+enum {
+	TIFF_TIFD_OFFSET_TAG = 0,
+	TIFF_TIFD_OFFSET_FORMAT = 2,
+	TIFF_TIFD_OFFSET_COUNT = 4,
+	TIFF_TIFD_OFFSET_DATA = 8,
+	TIFF_TIFD_SIZE = 12
+};
 
 
 
@@ -81,8 +86,8 @@ guint16 tiff_byte_get_int16(const guchar *f, TiffByteOrder bo)
 
 	if (bo == TIFF_BYTE_ORDER_INTEL)
 		return GUINT16_FROM_LE(align_buf);
-	else
-		return GUINT16_FROM_BE(align_buf);
+
+	return GUINT16_FROM_BE(align_buf);
 }
 
 guint32 tiff_byte_get_int32(const guchar *f, TiffByteOrder bo)
@@ -93,8 +98,8 @@ guint32 tiff_byte_get_int32(const guchar *f, TiffByteOrder bo)
 
 	if (bo == TIFF_BYTE_ORDER_INTEL)
 		return GUINT32_FROM_LE(align_buf);
-	else
-		return GUINT32_FROM_BE(align_buf);
+
+	return GUINT32_FROM_BE(align_buf); // NOLINT
 }
 
 #pragma GCC diagnostic push
@@ -125,7 +130,7 @@ void tiff_byte_put_int32_unused(guchar *f, guint32 n, TiffByteOrder bo)
 		}
 	else
 		{
-		align_buf = GUINT32_TO_BE(n);
+		align_buf = GUINT32_TO_BE(n); // NOLINT
 		}
 
 	memcpy(f, &align_buf, sizeof(guint32));
