@@ -18,26 +18,28 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#include <config.h>
-
-#ifdef HAVE_LUA
-
 #define _XOPEN_SOURCE
 
-#include <cstdio>
+#include "glua.h"
+
+#include <unistd.h>
+
 #include <cstring>
 #include <ctime>
 #include <memory>
+#include <utility>
 
 #include <glib.h>
 #include <lua.hpp>
 
-#include "main.h"
-#include "glua.h"
+#include "debug.h"
 #include "exif.h"
 #include "filedata.h"
+#include "main.h"
 #include "ui-fileops.h"
 
+struct ExifData;
+
 /**
  * @file
  * User API consists of the following namespaces:
@@ -259,13 +261,12 @@ static int lua_exif_get_datum(lua_State *L)
 			lua_pushnumber(L, datetime);
 			return 1;
 			}
-		else
-			{
-			lua_pushnil(L);
-			return 1;
-			}
+
+		lua_pushnil(L);
+		return 1;
 		}
-	else if (strcmp(key, "Exif.Photo.DateTimeDigitized") == 0)
+
+	if (strcmp(key, "Exif.Photo.DateTimeDigitized") == 0)
 		{
 		memset(&tm, 0, sizeof(tm));
 		if (value && strptime(value, "%Y:%m:%d %H:%M:%S", &tm))
@@ -274,11 +275,9 @@ static int lua_exif_get_datum(lua_State *L)
 			lua_pushnumber(L, datetime);
 			return 1;
 			}
-		else
-			{
-			lua_pushnil(L);
-			return 1;
-			}
+
+		lua_pushnil(L);
+		return 1;
 		}
 	lua_pushstring(L, value);
 	return 1;
@@ -410,7 +409,5 @@ gchar *lua_callvalue(FileData *fd, const gchar *file, const gchar *function)
 	g_free(tmp);
 	return data;
 }
-#else
-using dummy_variable = int;
-#endif
+
 /* vim: set shiftwidth=8 softtabstop=0 cindent cinoptions={1s: */
