@@ -33,7 +33,6 @@
 #include "md5-util.h"
 
 #include <cstdio>
-#include <cstring>
 #include <memory>
 
 using GQChecksumPtr = std::unique_ptr<GChecksum, decltype(&g_checksum_free)>;
@@ -136,7 +135,7 @@ gchar *md5_get_string_from_file(const gchar *path)
  * and assumes a NULL terminated string.
  */
 
-gchar *md5_digest_to_text(guchar digest[16])
+gchar *md5_digest_to_text(const guchar digest[16])
 {
 	static gchar hex_digits[] = "0123456789abcdef";
 	gchar *result;
