@@ -17,13 +17,19 @@
  * with this program; if not, write to the Free Software Foundation, Inc.,
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA. */
 
-#include "main.h"
 #include "options.h"
 
+#include <cstring>
+
+#include <gdk-pixbuf/gdk-pixbuf.h>
+
+#include "debug.h"
 #include "histogram.h" /* HCHAN_RGB */
 #include "image-overlay.h" /* OSD_SHOW_NOTHING */
-#include "layout.h"
+#include "intl.h"
 #include "layout-image.h"
+#include "layout.h"
+#include "main-defines.h"
 #include "misc.h"
 #include "rcfile.h"
 #include "ui-bookmark.h"
@@ -343,8 +349,8 @@ LayoutOptions *init_layout_options(LayoutOptions *options)
 	options->image_overlay.state = OSD_SHOW_NOTHING;
 	options->animate = TRUE;
 	options->bars_state.hidden = FALSE;
-	options->log_window.w = 520;
-	options->log_window.h = 400;
+	options->log_window.width = 520;
+	options->log_window.height = 400;
 	options->preferences_window.w = 700;
 	options->preferences_window.h = 600;
 	options->split_pane_sync = FALSE;
