@@ -21,8 +21,16 @@
 #ifndef OPTIONS_H
 #define OPTIONS_H
 
+#include <cairo.h>
+#include <gdk/gdk.h>
+#include <glib.h>
+
+#include "typedefs.h"
+
 struct SecureSaveInfo;
 
+#define COLOR_PROFILE_INPUTS 4
+
 /**
  * @enum DnDAction
  * drag and drop default action
@@ -531,12 +539,7 @@ struct LayoutOptions
 		gint histogram_mode;
 	} image_overlay;
 
-	struct {
-		gint w;
-		gint h;
-		gint x;
-		gint y;
-	} log_window;
+	GdkRectangle log_window;
 
 	struct {
 		gint w;
