@@ -22,18 +22,26 @@
  * used for the same purposes by the Print routines
  */
 
-#include "main.h"
 #include "osd.h"
 
+#include <cmath>
+#include <cstdlib>
+#include <cstring>
+
+#include <gdk/gdk.h>
+#include <glib-object.h>
+
+#include <config.h>
+
+#include "compat.h"
 #include "dnd.h"
 #include "exif.h"
 #include "glua.h"
+#include "intl.h"
 #include "metadata.h"
-#include "ui-fileops.h"
+#include "typedefs.h"
 #include "ui-misc.h"
 
-#include <cmath>
-
 static const gchar *predefined_tags[][2] = {
 	{"%name%",							N_("Name")},
 	{"%path:60%",						N_("Path")},
@@ -176,7 +184,7 @@ GtkWidget *osd_new(gint max_cols, GtkWidget *template_view)
 	gq_gtk_container_add(GTK_WIDGET(scrolled), viewport);
 	gtk_widget_show(viewport);
 
-	entries = (sizeof(predefined_tags) / sizeof(predefined_tags[0])) - 1;
+	entries = ((gdouble)sizeof(predefined_tags) / sizeof(predefined_tags[0])) - 1;
 	max_rows = ceil(entries / max_cols);
 
 	GtkGrid *grid;
@@ -236,11 +244,16 @@ static gchar *keywords_to_string(FileData *fd)
 
 gchar *image_osd_mkinfo(const gchar *str, FileData *fd, GHashTable *vars)
 {
-	gchar delim = '%', imp = '|', sep[] = " - ";
-	gchar *start, *end;
-	guint pos, prev;
+	gchar delim = '%';
+	gchar imp = '|';
+	gchar sep[] = " - ";
+	gchar *start;
+	gchar *end;
+	guint pos;
+	guint prev;
 	gboolean want_separator = FALSE;
-	gchar *name, *data;
+	gchar *name;
+	gchar *data;
 	GString *osd_info;
 	gchar *ret;
 
@@ -313,7 +326,7 @@ gchar *image_osd_mkinfo(const gchar *str, FileData *fd, GHashTable *vars)
 			{
 			data = metadata_read_string(fd, RATING_KEY, METADATA_PLAIN);
 			}
-#ifdef HAVE_LUA
+#if HAVE_LUA
 		else if (strncmp(name, "lua/", 4) == 0)
 			{
 			gchar *tmp;
@@ -360,10 +373,10 @@ gchar *image_osd_mkinfo(const gchar *str, FileData *fd, GHashTable *vars)
 				 * Examples:
 				 * "<i>*</i>\n" -> data is displayed in italics ended with a newline
 				 * "\n" 	-> ended with newline
-				 * "ISO *"	-> prefix data with "ISO " (ie. "ISO 100")
+				 * 'ISO *'	-> prefix data with 'ISO ' (ie. 'ISO 100')
 				 * "\**\*"	-> prefix data with a star, and append a star (ie. "*100*")
 				 * "\\*"	-> prefix data with an anti slash (ie "\100")
-				 * "Collection <b>*</b>\n" -> display data in bold prefixed by "Collection " and a newline is appended
+				 * 'Collection <b>*</b>\n' -> display data in bold prefixed by 'Collection ' and a newline is appended
 				 */
 				/** @FIXME using background / foreground colors lead to weird results.
 				 */
@@ -459,10 +472,8 @@ void osd_template_insert(GHashTable *vars, const gchar *keyword, const gchar *va
 		g_hash_table_insert(vars, const_cast<gchar *>(keyword), const_cast<gchar *>(value));
 		return;
 		}
-	else
-		{
-		g_hash_table_insert(vars, const_cast<gchar *>(keyword), g_strdup(value));
-		}
+
+	g_hash_table_insert(vars, const_cast<gchar *>(keyword), g_strdup(value));
 
 	if (flags & OSDT_FREE) g_free(const_cast<gchar *>(value));
 }
