@@ -21,6 +21,9 @@
 #ifndef OSD_H
 #define OSD_H
 
+#include <glib.h>
+#include <gtk/gtk.h>
+
 struct FileData;
 
 enum OsdTemplateFlags {
