@@ -24,14 +24,17 @@
 #include <cmath>
 
 #include "pan-item.h"
+#include "pan-types.h"
 #include "pan-util.h"
 #include "pan-view-filter.h"
+#include "typedefs.h"
 
 void pan_grid_compute(PanWindow *pw, FileData *dir_fd, gint *width, gint *height)
 {
 	GList *list;
 	GList *work;
-	gint x, y;
+	gint x;
+	gint y;
 	gint grid_size;
 	gint next_y;
 
