@@ -21,11 +21,19 @@
 
 #include "pan-view-filter.h"
 
+#include <cstddef>
+
+#include <glib-object.h>
+
+#include "compat.h"
+#include "filedata.h"
 #include "image.h"
+#include "intl.h"
+#include "main-defines.h"
 #include "metadata.h"
 #include "misc.h"
+#include "pan-types.h"
 #include "pan-view.h"
-#include "ui-fileops.h"
 #include "ui-misc.h"
 #include "ui-tabcomp.h"
 
@@ -144,7 +152,7 @@ static void pan_filter_kw_button_cb(GtkButton *widget, gpointer data)
 
 	/** @todo (xsdg): Fix filter element pointed object memory leak. */
 	ui->filter_elements = g_list_delete_link(ui->filter_elements, cb_state->filter_element);
-	g_object_unref(GTK_WIDGET(widget));
+	gtk_container_remove(GTK_CONTAINER(gtk_widget_get_parent(GTK_WIDGET(widget))), GTK_WIDGET(widget));
 	g_free(cb_state);
 
 	pan_filter_status(pw, _("Removed keyword…"));
@@ -227,7 +235,7 @@ void pan_filter_toggle_cb(GtkWidget *button, gpointer data)
 
 		parent = gtk_widget_get_parent(ui->filter_button_arrow);
 
-		g_object_unref(ui->filter_button_arrow);
+		gtk_container_remove(GTK_CONTAINER(parent), ui->filter_button_arrow);
 		ui->filter_button_arrow = gtk_image_new_from_icon_name(GQ_ICON_PAN_UP, GTK_ICON_SIZE_BUTTON);
 
 		gq_gtk_box_pack_start(GTK_BOX(parent), ui->filter_button_arrow, FALSE, FALSE, 0);
@@ -241,7 +249,7 @@ void pan_filter_toggle_cb(GtkWidget *button, gpointer data)
 
 		parent = gtk_widget_get_parent(ui->filter_button_arrow);
 
-		g_object_unref(ui->filter_button_arrow);
+		gtk_container_remove(GTK_CONTAINER(parent), ui->filter_button_arrow);
 		ui->filter_button_arrow = gtk_image_new_from_icon_name(GQ_ICON_PAN_DOWN, GTK_ICON_SIZE_BUTTON);
 
 		gq_gtk_box_pack_start(GTK_BOX(parent), ui->filter_button_arrow, FALSE, FALSE, 0);
@@ -319,13 +327,11 @@ static gboolean pan_view_list_contains_kw_pattern(GList *haystack, PanViewFilter
 			}
 		return FALSE;
 		}
-	else
-		{
-		// regex compile failed; fall back to exact string match.
-		GList *found_elem = g_list_find_custom(haystack, filter->keyword, reinterpret_cast<GCompareFunc>(g_strcmp0));
-		if (found_elem && found_kw) *found_kw = static_cast<gchar *>(found_elem->data);
-		return !!found_elem;
-		}
+
+	// regex compile failed; fall back to exact string match.
+	GList *found_elem = g_list_find_custom(haystack, filter->keyword, reinterpret_cast<GCompareFunc>(g_strcmp0));
+	if (found_elem && found_kw) *found_kw = static_cast<gchar *>(found_elem->data);
+	return !!found_elem;
 }
 
 gboolean pan_filter_fd_list(GList **fd_list, GList *filter_elements, gint filter_classes)
