@@ -21,9 +21,21 @@
 
 #include "pan-view-search.h"
 
+#include <cstdlib>
+#include <cstring>
+#include <ctime>
+
+#include <glib-object.h>
+
+#include "compat.h"
+#include "filedata.h"
 #include "image.h"
+#include "intl.h"
+#include "main-defines.h"
 #include "misc.h"
 #include "pan-calendar.h"
+#include "pan-item.h"
+#include "pan-types.h"
 #include "pan-util.h"
 #include "pan-view.h"
 #include "ui-misc.h"
@@ -432,7 +444,7 @@ void pan_search_toggle_cb(GtkWidget *button, gpointer data)
 
 		parent = gtk_widget_get_parent(ui->search_button_arrow);
 
-		g_object_unref(ui->search_button_arrow);
+		gtk_container_remove(GTK_CONTAINER(parent), ui->search_button_arrow);
 		ui->search_button_arrow = gtk_image_new_from_icon_name(GQ_ICON_PAN_UP, GTK_ICON_SIZE_BUTTON);
 
 		gq_gtk_box_pack_start(GTK_BOX(parent), ui->search_button_arrow, FALSE, FALSE, 0);
@@ -446,7 +458,7 @@ void pan_search_toggle_cb(GtkWidget *button, gpointer data)
 
 		parent = gtk_widget_get_parent(ui->search_button_arrow);
 
-		g_object_unref(ui->search_button_arrow);
+		gtk_container_remove(GTK_CONTAINER(parent), ui->search_button_arrow);
 		ui->search_button_arrow = gtk_image_new_from_icon_name(GQ_ICON_PAN_DOWN, GTK_ICON_SIZE_BUTTON);
 
 		gq_gtk_box_pack_start(GTK_BOX(parent), ui->search_button_arrow, FALSE, FALSE, 0);
