@@ -22,6 +22,9 @@
 #ifndef PREFERENCES_H
 #define PREFERENCES_H
 
+#include <glib.h>
+#include <gtk/gtk.h>
+
 struct LayoutWindow;
 
 void show_config_window(LayoutWindow *lw);
