@@ -19,27 +19,39 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#include "main.h"
 #include "rcfile.h"
 
-#include "bar.h"
+#include <cstdlib>
+#include <cstring>
+
+#include <gdk-pixbuf/gdk-pixbuf.h>
+#include <gtk/gtk.h>
+
+#include <config.h>
+
 #include "bar-comment.h"
 #include "bar-exif.h"
+#include "bar-gps.h"
 #include "bar-histogram.h"
 #include "bar-keywords.h"
 #include "bar-rating.h"
 #include "bar-sort.h"
+#include "bar.h"
+#include "debug.h"
+#include "dupe.h"
 #include "editors.h"
 #include "filefilter.h"
+#include "intl.h"
+#include "layout-util.h"
+#include "layout.h"
+#include "main-defines.h"
+#include "metadata.h"
+#include "options.h"
 #include "pixbuf-renderer.h"
 #include "secure-save.h"
 #include "slideshow.h"
+#include "typedefs.h"
 #include "ui-fileops.h"
-#include "layout-util.h"
-#include "bar.h"
-#include "metadata.h"
-#include "bar-gps.h"
-#include "dupe.h"
 #include "ui-utildlg.h"
 
 /*
@@ -251,7 +263,8 @@ gboolean read_int_option_clamp(const gchar *option, const gchar *label, const gc
 
 void write_int_unit_option(GString *str, gint, const gchar *label, gint n, gint subunits)
 {
-	gint l, r;
+	gint l;
+	gint r;
 
 	if (subunits > 0)
 		{
@@ -269,8 +282,10 @@ void write_int_unit_option(GString *str, gint, const gchar *label, gint n, gint
 
 gboolean read_int_unit_option(const gchar *option, const gchar *label, const gchar *value, gint *n, gint subunits)
 {
-	gint l, r;
-	gchar *ptr, *buf;
+	gint l;
+	gint r;
+	gchar *ptr;
+	gchar *buf;
 
 	if (g_ascii_strcasecmp(option, label) != 0) return FALSE;
 	if (!n) return FALSE;
@@ -570,7 +585,7 @@ static void write_global_attributes(GString *outstr, gint indent)
 static void write_color_profile(GString *outstr, gint indent)
 {
 	gint i;
-#ifndef HAVE_LCMS
+#if !HAVE_LCMS
 	g_string_append_printf(outstr, "<!-- NOTICE: %s was not built with support for color profiles,\n"
 				"		 color profile options will have no effect.\n-->\n", GQ_APPNAME);
 #endif
@@ -1397,7 +1412,7 @@ static void options_parse_global(GQParserData *parser_data, GMarkupParseContext
 
 static void options_parse_global_end(GQParserData *, GMarkupParseContext *, const gchar *, gpointer, GError **)
 {
-#ifndef HAVE_EXIV2
+#if !HAVE_EXIV2
 	/* some options do not work without exiv2 */
 	options->metadata.save_in_image_file = FALSE;
 	options->metadata.save_legacy_format = TRUE;
@@ -1454,8 +1469,7 @@ static void options_parse_bar(GQParserData *parser_data, GMarkupParseContext *,
 			}
 		options_parse_func_push(parser_data, options_parse_leaf, nullptr, nullptr);
 		}
-#ifdef HAVE_LIBCHAMPLAIN
-#ifdef HAVE_LIBCHAMPLAIN_GTK
+#if HAVE_LIBCHAMPLAIN && HAVE_LIBCHAMPLAIN_GTK
 	else if (g_ascii_strcasecmp(element_name, "pane_gps") == 0)
 		{
 		/* Use this flag to determine if --disable-clutter has been issued */
@@ -1474,7 +1488,6 @@ static void options_parse_bar(GQParserData *parser_data, GMarkupParseContext *,
 			options_parse_func_push(parser_data, options_parse_leaf, nullptr, nullptr);
 			}
 		}
-#endif
 #endif
 	else if (g_ascii_strcasecmp(element_name, "pane_exif") == 0)
 		{
