@@ -24,6 +24,7 @@
 #include <cmath>
 #include <cstdlib>
 #include <cstring>
+#include <utility>
 
 #include <cairo.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
@@ -60,6 +61,13 @@ enum ExifOrientationType {
 };
 #endif
 
+namespace
+{
+
+constexpr size_t COLOR_BYTES = 3; /* rgb */
+
+} // namespace
+
 struct QueueData;
 
 struct ImageTile
@@ -887,10 +895,6 @@ static GdkPixbuf *rt_get_spare_tile(RendererTiles *rt)
 	return rt->spare_tile;
 }
 
-enum {
-	COLOR_BYTES = 3	/* rgb */
-};
-
 static void rt_tile_rotate_90_clockwise(RendererTiles *rt, GdkPixbuf **tile, gint x, gint y, gint w, gint h)
 {
 	GdkPixbuf *src = *tile;
@@ -1509,14 +1513,11 @@ static void rt_tile_render(RendererTiles *rt, ImageTile *it,
 
 		switch (orientation)
 			{
-			gdouble tmp;
 			case EXIF_ORIENTATION_LEFT_TOP:
 			case EXIF_ORIENTATION_RIGHT_TOP:
 			case EXIF_ORIENTATION_RIGHT_BOTTOM:
 			case EXIF_ORIENTATION_LEFT_BOTTOM:
-				tmp = scale_x;
-				scale_x = scale_y;
-				scale_y = tmp;
+				std::swap(scale_x, scale_y);
 				break;
 			default:
 				/* nothing to do */
@@ -1558,7 +1559,7 @@ static void rt_tile_render(RendererTiles *rt, ImageTile *it,
 		{
 		cairo_t *cr;
 
-		if (pr->func_post_process && !(pr->post_process_slow && fast))
+		if (pr->func_post_process && (!pr->post_process_slow || !fast))
 			pr->func_post_process(pr, &it->pixbuf, x, y, w, h, pr->post_process_user_data);
 
 		cr = cairo_create(it->surface);
