@@ -18,13 +18,22 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
+#include "secure-save.h"
+
+#include <cerrno>
+#include <cstdarg>
 #include <memory>
 
-#include "main.h"
-#include <glib/gprintf.h>
+#include <sys/stat.h>
+#include <unistd.h>
 #include <utime.h>
 
-#include "secure-save.h"
+#include <glib/gprintf.h>
+
+#include <config.h>
+
+#include "debug.h"
+#include "intl.h"
 
 /**
  * @file secure-save.cc
@@ -121,7 +130,7 @@ secure_open_umask(const gchar *file_name)
 			/* Not a regular file, secure_save is disabled. */
 			ssi->secure_save = FALSE;
 		} else {
-#ifdef HAVE_ACCESS
+#if HAVE_ACCESS
 			/* XXX: access() do not work with setuid programs. */
 			if (access(ssi->file_name, R_OK | W_OK) < 0) {
 				ssi->err = errno;
@@ -241,15 +250,15 @@ secure_close(SecureSaveInfo *ssi)
 	 * fclose() (which call fflush() again, but the first one is needed since
 	 * it doesn't make much sense to flush kernel buffers and then libc buffers,
 	 * while closing file releases file descriptor we need to call fsync(). */
-#if defined(HAVE_FFLUSH) || defined(HAVE_FSYNC)
+#if HAVE_FFLUSH || HAVE_FSYNC
 	if (ssi->secure_save) {
 		gboolean fail = FALSE;
 
-#ifdef HAVE_FFLUSH
+#if HAVE_FFLUSH
 		fail = (fflush(ssi->fp) == EOF);
 #endif
 
-#ifdef HAVE_FSYNC
+#if HAVE_FSYNC
 		if (!fail) fail = fsync(fileno(ssi->fp));
 #endif
 
