@@ -19,15 +19,21 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#include "main.h"
 #include "shortcuts.h"
 
+#include <glib-object.h>
+#include <glib.h>
+
 #include "collect.h"
+#include "compat.h"
+#include "intl.h"
 #include "layout.h"
-#include "utilops.h"
+#include "main-defines.h"
 #include "ui-bookmark.h"
 #include "ui-fileops.h"
 #include "ui-misc.h"
+#include "ui-utildlg.h"
+#include "utilops.h"
 
 struct ShortcutsData
 {
