@@ -19,15 +19,25 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#include "main.h"
 #include "toolbar.h"
 
-#include "layout-util.h"
-#include "ui-fileops.h"
-#include "ui-misc.h"
-#include "pixbuf-util.h"
-#include "ui-menu.h"
+#include <cstddef>
+
+#include <gdk-pixbuf/gdk-pixbuf.h>
+#include <glib-object.h>
+#include <glib.h>
+
+#include <config.h>
+
+#include "compat.h"
 #include "editors.h"
+#include "intl.h"
+#include "layout-util.h"
+#include "layout.h"
+#include "main-defines.h"
+#include "ui-fileops.h"
+#include "ui-menu.h"
+#include "ui-misc.h"
 
 /** Implements the user-definable toolbar function
  * Called from the Preferences/toolbar tab
@@ -215,7 +225,7 @@ static void toolbarlist_add_button(const gchar *name, const gchar *label,
 	toolbar_entry->name = g_strdup(name);
 	toolbar_entry->stock_id = g_strdup(stock_id);
 
-#ifdef HAVE_GTK4
+#if HAVE_GTK4
 	gesture = gtk_gesture_click_new();
 	gtk_widget_add_controller(toolbar_entry->button, GTK_EVENT_CONTROLLER(gesture));
 #else
@@ -234,7 +244,8 @@ static void toolbarlist_add_button(const gchar *name, const gchar *label,
 		if (pixbuf)
 			{
 			GdkPixbuf *scaled;
-			gint w, h;
+			gint w;
+			gint h;
 
 			w = h = 16;
 			gtk_icon_size_lookup(GTK_ICON_SIZE_BUTTON, &w, &h);
