@@ -19,14 +19,25 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#include "main.h"
 #include "trash.h"
-#include "utilops.h"
-#include "window.h"
 
+#include <unistd.h>
+
+#include <cstdlib>
+
+#include <gio/gio.h>
+
+#include "debug.h"
 #include "editors.h"
 #include "filedata.h"
+#include "intl.h"
+#include "main-defines.h"
+#include "options.h"
+#include "typedefs.h"
 #include "ui-fileops.h"
+#include "ui-utildlg.h"
+#include "utilops.h"
+#include "window.h"
 
 /*
  *--------------------------------------------------------------------------
