@@ -19,19 +19,27 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
+#include "ui-help.h"
+
 #include <cstdio>
 #include <cstring>
 
-#include "main.h"
-#include "ui-help.h"
+#include <gdk/gdk.h>
+#include <glib-object.h>
 
+#include "compat.h"
+#include "debug.h"
+#include "intl.h"
+#include "main-defines.h"
 #include "ui-fileops.h"
 #include "ui-misc.h"
 #include "window.h"
 
 
-#define HELP_WINDOW_WIDTH 650
-#define HELP_WINDOW_HEIGHT 350
+enum {
+	HELP_WINDOW_WIDTH = 650,
+	HELP_WINDOW_HEIGHT = 350
+};
 
 
 /*
@@ -47,7 +55,8 @@ static void help_window_scroll(GtkWidget *text, const gchar *key)
 	gchar *needle;
 	GtkTextBuffer *buffer;
 	GtkTextIter iter;
-	GtkTextIter start, end;
+	GtkTextIter start;
+	GtkTextIter end;
 
 	if (!text || !key) return;
 
@@ -91,7 +100,8 @@ static void help_window_load_text(GtkWidget *text, const gchar *path)
 	gchar s_buf[1024];
 	GtkTextBuffer *buffer;
 	GtkTextIter iter;
-	GtkTextIter start, end;
+	GtkTextIter start;
+	GtkTextIter end;
 
 	if (!text || !path) return;
 
