@@ -19,15 +19,22 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#include <cstring>
-#include <dirent.h>
-#include <sys/types.h>
-
-#include "main.h"
 #include "ui-tabcomp.h"
 
+#include <dirent.h>
+
+#include <cstring>
+
+#include <gdk/gdk.h>
+#include <glib-object.h>
+
+#include "compat.h"
+#include "debug.h"
 #include "history-list.h"
+#include "intl.h"
+#include "main-defines.h"
 #include "misc.h"	/* expand_tilde() */
+#include "options.h"
 #include "ui-fileops.h"
 #include "ui-utildlg.h"
 
@@ -208,7 +215,7 @@ void tab_completion_iter_menu_items(GtkWidget *widget, gpointer data)
 		const gchar *prefix = filename_from_path(entry_text);
 		guint prefix_len = strlen(prefix);
 
-		if (strlen(text) < prefix_len || strncmp(text, prefix, prefix_len))
+		if (strlen(text) < prefix_len || strncmp(text, prefix, prefix_len) != 0)
 			{
 			/* Hide menu items not matching */
 			gtk_widget_hide(widget);
@@ -405,15 +412,13 @@ static gboolean tab_completion_do(TabCompData *td)
 			g_free(entry_dir);
 			return home_exp;
 			}
-		else
-			{
-			gchar *buf = g_strconcat(entry_dir, G_DIR_SEPARATOR_S, NULL);
-			gq_gtk_entry_set_text(GTK_ENTRY(td->entry), buf);
-			gtk_editable_set_position(GTK_EDITABLE(td->entry), strlen(buf));
-			g_free(buf);
-			g_free(entry_dir);
-			return TRUE;
-			}
+
+		gchar *buf = g_strconcat(entry_dir, G_DIR_SEPARATOR_S, NULL);
+		gq_gtk_entry_set_text(GTK_ENTRY(td->entry), buf);
+		gtk_editable_set_position(GTK_EDITABLE(td->entry), strlen(buf));
+		g_free(buf);
+		g_free(entry_dir);
+		return TRUE;
 		}
 
 	ptr = const_cast<gchar *>(filename_from_path(entry_dir));
@@ -463,52 +468,51 @@ static gboolean tab_completion_do(TabCompData *td)
 				g_free(entry_dir);
 				return TRUE;
 				}
-			else
-				{
-				gsize c = strlen(entry_file);
-				gboolean done = FALSE;
-				auto test_file = static_cast<gchar *>(poss->data);
 
-				while (!done)
+			gsize c = strlen(entry_file);
+			gboolean done = FALSE;
+			auto test_file = static_cast<gchar *>(poss->data);
+
+			while (!done)
+				{
+				list = poss;
+				if (!list) done = TRUE;
+				while (list && !done)
 					{
-					list = poss;
-					if (!list) done = TRUE;
-					while (list && !done)
+					auto file = static_cast<gchar *>(list->data);
+					if (strlen(file) < c || strncmp(test_file, file, c) != 0)
 						{
-						auto file = static_cast<gchar *>(list->data);
-						if (strlen(file) < c || strncmp(test_file, file, c) != 0)
-							{
-							done = TRUE;
-							}
-						list = list->next;
+						done = TRUE;
 						}
-					c++;
+					list = list->next;
 					}
-				c -= 2;
-				if (c > 0)
-					{
-					gchar *file;
-					gchar *buf;
-					file = g_strdup(test_file);
-					file[c] = '\0';
-					buf = g_build_filename(entry_dir, file, NULL);
-					gq_gtk_entry_set_text(GTK_ENTRY(td->entry), buf);
-					gtk_editable_set_position(GTK_EDITABLE(td->entry), strlen(buf));
+				c++;
+				}
+			c -= 2;
+			if (c > 0)
+				{
+				gchar *file;
+				gchar *buf;
+				file = g_strdup(test_file);
+				file[c] = '\0';
+				buf = g_build_filename(entry_dir, file, NULL);
+				gq_gtk_entry_set_text(GTK_ENTRY(td->entry), buf);
+				gtk_editable_set_position(GTK_EDITABLE(td->entry), strlen(buf));
 
 #ifdef TAB_COMPLETION_ENABLE_POPUP_MENU
 
-					poss = g_list_sort(poss, simple_sort);
-					tab_completion_popup_list(td, poss);
+				poss = g_list_sort(poss, simple_sort);
+				tab_completion_popup_list(td, poss);
 
 #endif
 
-					g_free(file);
-					g_free(buf);
-					g_list_free(poss);
-					g_free(entry_dir);
-					return TRUE;
-					}
+				g_free(file);
+				g_free(buf);
+				g_list_free(poss);
+				g_free(entry_dir);
+				return TRUE;
 				}
+
 			g_list_free(poss);
 			}
 		}
@@ -588,8 +592,7 @@ static void tab_completion_button_size_allocate(GtkWidget *button, GtkAllocation
 
 		gtk_widget_get_allocation(button, &button_allocation);
 		button_allocation.height = parent_allocation.height;
-		button_allocation.y = parent_allocation.y +
-			(parent_allocation.height - parent_allocation.height) / 2;
+		button_allocation.y = parent_allocation.y;
 		gtk_widget_size_allocate(button, &button_allocation);
 		}
 }
