@@ -19,13 +19,26 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#include <cstring>
-
-#include "main.h"
 #include "ui-utildlg.h"
 
+#include <cstdint>
+#include <cstdio>
+#include <cstring>
+#include <ctime>
+
+#include <gdk/gdk.h>
+#include <gio/gio.h>
+#include <glib-object.h>
+
+#include <config.h>
+
+#include "compat.h"
+#include "debug.h"
 #include "filedata.h"
+#include "intl.h"
+#include "main-defines.h"
 #include "misc.h"
+#include "options.h"
 #include "rcfile.h"
 #include "ui-fileops.h"
 #include "ui-misc.h"
@@ -108,7 +121,10 @@ void generic_dialog_close(GenericDialog *gd)
 	gchar *ident_string;
 	gchar *full_title;
 	gchar *actual_title;
-	gint x, y, h, w;
+	gint x;
+	gint y;
+	gint h;
+	gint w;
 
 	gdk_window_get_root_origin(gtk_widget_get_window (gd->dialog), &x, &y);
 	w = gdk_window_get_width(gtk_widget_get_window (gd->dialog));
@@ -384,7 +400,10 @@ static void generic_dialog_setup(GenericDialog *gd,
 				 void (*cancel_cb)(GenericDialog *, gpointer), gpointer data)
 {
 	GtkWidget *vbox;
-	gint x, y, w, h;
+	gint x;
+	gint y;
+	gint w;
+	gint h;
 	GtkWidget *scrolled;
 
 	gd->auto_close = auto_close;
@@ -534,7 +553,7 @@ static gboolean appimage_notification_close_cb(gpointer data)
 
 	if (appimage_data->window)
 		{
-		g_object_unref(appimage_data->window);
+		gq_gtk_widget_destroy(appimage_data->window);
 		}
 
 	g_thread_pool_free(appimage_data->thread_pool, TRUE, TRUE);
@@ -598,7 +617,9 @@ void appimage_notification_func(gpointer data, gpointer)
 	GSocketConnectable *geeqie_github;
 	struct tm current_version_date;
 	int64_t file_github_date;
-	unsigned int year, month, day;
+	unsigned int year;
+	unsigned int month;
+	unsigned int day;
 
 	/* If this is a release version, do not check for updates */
 	if (g_strrstr(VERSION, "git"))
