@@ -22,9 +22,10 @@
 #ifndef UI_UTILDLG_H
 #define UI_UTILDLG_H
 
-struct FileData;
+#include <glib.h>
+#include <gtk/gtk.h>
 
-#define GENERIC_DIALOG(gd) ((GenericDialog *)gd)
+struct FileData;
 
 struct GenericDialog
 {
@@ -43,6 +44,8 @@ struct GenericDialog
 
 };
 
+#define GENERIC_DIALOG(gd) ((GenericDialog *)gd)
+
 struct FileDialog
 {
 	GenericDialog gd;
@@ -72,7 +75,7 @@ GtkWidget *generic_dialog_add_button(GenericDialog *gd, const gchar *icon_name,
 				     void (*func_cb)(GenericDialog *, gpointer), gboolean is_default);
 void generic_dialog_attach_default(GenericDialog *gd, GtkWidget *widget);
 
-GtkWidget *generic_dialog_add_message(GenericDialog *gd, const gchar *icon_stock_id,
+GtkWidget *generic_dialog_add_message(GenericDialog *gd, const gchar *icon_name,
 				      const gchar *heading, const gchar *text, gboolean expand);
 
 gboolean generic_dialog_get_alternative_button_order(GtkWidget *widget);
