@@ -18,10 +18,12 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#include "main.h"
 #include "uri-utils.h"
 
+#include "debug.h"
 #include "filedata.h"
+#include "intl.h"
+#include "main-defines.h"
 #include "ui-fileops.h"
 #include "ui-utildlg.h"
 
