@@ -19,11 +19,20 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#include "main.h"
 #include "view-dir-list.h"
 
+#include <unistd.h>
+
+#include <cstdlib>
+#include <cstring>
+
+#include <gdk-pixbuf/gdk-pixbuf.h>
+#include <glib-object.h>
+
 #include "filedata.h"
 #include "layout.h"
+#include "options.h"
+#include "typedefs.h"
 #include "ui-fileops.h"
 #include "ui-tree-edit.h"
 #include "view-dir.h"
@@ -33,7 +42,7 @@ struct ViewDirInfoList
 	GList *list;
 };
 
-#define VDLIST(_vd_) ((ViewDirInfoList *)(_vd_->info))
+#define VDLIST(_vd_) ((ViewDirInfoList *)((_vd_)->info))
 
 
 /*
