@@ -19,11 +19,21 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#include "main.h"
 #include "view-dir-tree.h"
 
+#include <unistd.h>
+
+#include <cstdlib>
+#include <cstring>
+
+#include <gdk-pixbuf/gdk-pixbuf.h>
+#include <glib-object.h>
+
+#include "debug.h"
 #include "filedata.h"
 #include "layout.h"
+#include "options.h"
+#include "typedefs.h"
 #include "ui-fileops.h"
 #include "ui-tree-edit.h"
 #include "view-dir.h"
@@ -34,7 +44,7 @@ struct ViewDirInfoTree
 	gint busy_ref;
 };
 
-#define VDTREE(_vd_) ((ViewDirInfoTree *)(_vd_->info))
+#define VDTREE(_vd_) ((ViewDirInfoTree *)((_vd_)->info))
 
 
 struct PathData
@@ -228,7 +238,8 @@ static void vdtree_dnd_drop_expand(ViewDir *vd)
 static GList *parts_list(const gchar *path)
 {
 	GList *list = nullptr;
-	const gchar *strb, *strp;
+	const gchar *strb;
+	const gchar *strp;
 	gint l;
 
 	strp = path;
@@ -737,7 +748,8 @@ gboolean vdtree_set_fd(ViewDir *vd, FileData *dir_fd)
 	if (vd_find_row(vd, fd, &iter))
 		{
 		GtkTreeModel *store;
-		GtkTreePath *tpath, *old_tpath;
+		GtkTreePath *tpath;
+		GtkTreePath *old_tpath;
 		GtkTreeSelection *selection;
 
 		store = gtk_tree_view_get_model(GTK_TREE_VIEW(vd->view));
@@ -997,28 +1009,23 @@ static gint vdtree_sort_cb(GtkTreeModel *store, GtkTreeIter *a, GtkTreeIter *b,
 			{
 			return strcmp(nda->fd->collate_key_name_natural, ndb->fd->collate_key_name_natural);
 			}
-		else
-			{
-			return strcmp(nda->fd->collate_key_name_nocase_natural, ndb->fd->collate_key_name_nocase_natural);
-			}
+
+		return strcmp(nda->fd->collate_key_name_nocase_natural, ndb->fd->collate_key_name_nocase_natural);
 		}
-	else if (vd->layout->options.dir_view_list_sort.method == SORT_TIME)
+
+	if (vd->layout->options.dir_view_list_sort.method == SORT_TIME)
 		{
 		if (nda->fd->date < ndb->fd->date) return -1;
 		if (nda->fd->date > ndb->fd->date) return 1;
 		return 0;
 		}
-	else
+
+	if (vd->layout->options.dir_view_list_sort.case_sensitive == TRUE)
 		{
-		if (vd->layout->options.dir_view_list_sort.case_sensitive == TRUE)
-			{
-			return strcmp(nda->fd->collate_key_name, ndb->fd->collate_key_name);
-			}
-		else
-			{
-			return strcmp(nda->fd->collate_key_name_nocase, ndb->fd->collate_key_name_nocase);
-			}
+		return strcmp(nda->fd->collate_key_name, ndb->fd->collate_key_name);
 		}
+
+	return strcmp(nda->fd->collate_key_name_nocase, ndb->fd->collate_key_name_nocase);
 }
 
 /*
