@@ -21,6 +21,13 @@
 #ifndef VIEW_DIR_H
 #define VIEW_DIR_H
 
+#include <gdk-pixbuf/gdk-pixbuf.h>
+#include <gdk/gdk.h>
+#include <glib.h>
+#include <gtk/gtk.h>
+
+#include "typedefs.h"
+
 struct FileData;
 struct LayoutWindow;
 
