@@ -18,22 +18,32 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#include "main.h"
 #include "view-file.h"
 
+#include <gdk/gdk.h>
+#include <glib-object.h>
+
+#include "archives.h"
+#include "compat.h"
+#include "debug.h"
 #include "dupe.h"
+#include "filedata.h"
 #include "history-list.h"
+#include "intl.h"
 #include "layout.h"
+#include "main-defines.h"
+#include "main.h"
 #include "menu.h"
 #include "misc.h"
-#include "pixbuf-util.h"
+#include "options.h"
 #include "thumb.h"
-#include "ui-menu.h"
 #include "ui-fileops.h"
+#include "ui-menu.h"
 #include "ui-misc.h"
+#include "ui-utildlg.h"
 #include "utilops.h"
-#include "view-file/view-file-list.h"
 #include "view-file/view-file-icon.h"
+#include "view-file/view-file-list.h"
 #include "window.h"
 
 /*
@@ -828,7 +838,7 @@ static void vf_destroy_cb(GtkWidget *widget, gpointer data)
 		{
 		g_signal_handlers_disconnect_matched(G_OBJECT(vf->popup), G_SIGNAL_MATCH_DATA,
 						     0, 0, nullptr, nullptr, vf);
-		g_object_unref(vf->popup);
+		gq_gtk_widget_destroy(vf->popup);
 		}
 
 	if (vf->read_metadata_in_idle_id)
@@ -928,7 +938,7 @@ static gboolean vf_marks_tooltip_cb(GtkWidget *widget,
 	gtk_entry_set_icon_from_icon_name(GTK_ENTRY(mte->edit_widget),
 				      GTK_ENTRY_ICON_SECONDARY, GQ_ICON_CLEAR);
 	gtk_entry_set_icon_tooltip_text(GTK_ENTRY(mte->edit_widget),
-					GTK_ENTRY_ICON_SECONDARY, "Clear");
+					GTK_ENTRY_ICON_SECONDARY, _("Clear"));
 	g_signal_connect(GTK_ENTRY(mte->edit_widget), "icon-press",
 			 G_CALLBACK(vf_marks_filter_on_icon_press), mte);
 
@@ -1563,12 +1573,10 @@ gboolean vf_stars_cb(gpointer data)
 			{
 			return G_SOURCE_CONTINUE;
 			}
-		else
-			{
-			vf->stars_filedata = nullptr;
-			vf->stars_id = 0;
-			return G_SOURCE_REMOVE;
-			}
+
+		vf->stars_filedata = nullptr;
+		vf->stars_id = 0;
+		return G_SOURCE_REMOVE;
 		}
 
 	return G_SOURCE_REMOVE;
@@ -1826,7 +1834,7 @@ static void vf_read_metadata_in_idle_finished_cb(gpointer data)
 {
 	auto vf = static_cast<ViewFile *>(data);
 
-	vf_thumb_status(vf, 0.0, "Loading meta...");
+	vf_thumb_status(vf, 0.0, _("Loading meta..."));
 	vf->read_metadata_in_idle_id = 0;
 }
 
