@@ -18,10 +18,23 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#include "main.h"
 #include "window.h"
 
+#include <cstdio>
+#include <cstring>
+
+#include <gdk-pixbuf/gdk-pixbuf.h>
+#include <gdk/gdk.h>
+#include <glib-object.h>
+
+#include <config.h>
+
+#include "debug.h"
+#include "intl.h"
+#include "main-defines.h"
+#include "main.h"
 #include "misc.h"
+#include "options.h"
 #include "pixbuf-util.h"
 #include "ui-fileops.h"
 #include "ui-help.h"
@@ -33,7 +46,7 @@ GtkWidget *window_new(const gchar *role, const gchar *icon, const gchar *icon_fi
 	gchar *title;
 	GtkWidget *window;
 
-#ifdef HAVE_GTK4
+#if HAVE_GTK4
 	window = gtk_window_new();
 #else
 	window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
